<?php
namespace PFAdviceServer;
require_once 'ComposerAdvicePortafirmas.php';
require_once 'WSComunSoapServer.php';

class PFAdviceSOAPServer {

	private $fnCallback = null;

	/**
	 * Constructor estatico del WS
	 *
	 * @access	public
	 * @param  	string		$fnCallback	Nombre de la funcion que manejar la peticin a invocar al activarse el servicio.
	 * @param	true|string	$serviceURL	Si es true, genera automaticamente la URL de escucha. Si es un string, utiliza la URL de escucha indicada.
	 * @param	string	$rutaPlantillaWSDL	Ruta a las plantillas de WSDL y XSD. Si es nulo, asume el mismo directorio.
	 * @return	PFAdviceSOAPServer	Instancia del servidor.
	 */
	public static function createSoapServer($fnCallback, $serviceURL = true, $rutaPlantillas = null) {
		// Prepara la URL del servidor
		$currentURL = (self::isSecure() ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[PHP_SELF]";
		if (is_string($serviceURL)) {
			$currentURL = $serviceURL;
		}

		if (empty ($rutaPlantillas)) {
			$rutaPlantillas = __DIR__ . DIRECTORY_SEPARATOR;
		}
		// Generacion interna de WSDL
		if (isset($_REQUEST['wsdl'])) {
			$wsdlContent = file_get_contents($rutaPlantillas.'PFAdviceWS.wsdl');
			$wsdlContent = str_replace('http://servidor/AdviceService', $currentURL, $wsdlContent);
			ob_clean();
			header('Content-type: application/xml');
			echo $wsdlContent;
			ob_flush();
			die;
		}

		// Generacion interna de type
		if (isset($_REQUEST['types']) && ($serviceURL !== false)) {
			$xsdContent = file_get_contents($rutaPlantillas.'WebServiceTypes.xsd');
			ob_clean();
			header('Content-type: application/xml');
			echo $xsdContent;
			ob_flush();
			die;
		}


		$opts = array (
			'typemap' => array(
				array(
					'type_name' => 'userJob',
					'type_ns' => 'urn:juntadeandalucia:cice:pfirma:type:v2.0',
					'from_xml' => 'PFAdviceServer\PFAdviceSOAPServer::userJob_from_xml',
				)
			)
		);

		$service = new PFAdviceSOAPServer('PFAdviceSOAPService');
		$service->fnCallback = $fnCallback;

		//$server = new \SoapServer($currentURL . '?wsdl', $opts);
		$server = new \WSComunSoapServer($currentURL . '?wsdl', $opts);
		$server->setObject($service);
		return $server;
	}

	// Tratamiento especifico de clases especiales
	public static function userJob_from_xml($xml)
	{
		$sxe = simplexml_load_string($xml);

		// Crea objeto y establece datos comunes/obligatorios
		$obj = new \stdClass();
		$obj->identifier = (string) $sxe->identifier;

		// Establece el tipo exacto
		$attributes = "@attributes";
		if (isset($sxe->attributes('xsi', TRUE)->type)) {
			$obj->$attributes = array('type' => (string) $sxe->attributes('xsi', TRUE)->type);
		} elseif (isset($sxe->attributes()->type))  {
			$obj->$attributes = array('type' => (string) $sxe->attributes()->type);
		}

		$isUser = null;
		if (SoapObject::endsWith((string) $sxe->attributes()->type, ':user')) {
			$isUser = true;
		} elseif (SoapObject::endsWith((string) $sxe->attributes()->type, ':job')) {
			$isUser = false;
		}

		// Tipologia especifica
		if ($isUser) {
			// Caso especifico: User
			if (isset($sxe->name)) {
				$obj->name = (string) $sxe->name;
			}
			if (isset($sxe->surname1)) {
				$obj->surname1 = (string) $sxe->surname1;
			}
			if (isset($sxe->surname2)) {
				$obj->surname2 = (string) $sxe->surname2;
			}
		} else {
			// Caso especifico: Job
			if (isset($sxe->description)) {
				$obj->description = (string) $sxe->description;
			}
		}

		return $obj;
	}



	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	private function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}


	/**
	 * Constructor privado del WS.
	 * Uso interno. Utilizar "createSoapServer" en su lugar
	 *
	 * @access	public
	 * @return	PFAdviceSOAPServer	Instancia del servidor.
	 */
	protected function __construct(){}


	/**
	 * Mtodo de tratamiento de peticiones "updateRequestStatus"
	 * Invoca al mtodo suministrado por el programador final.
	 * Uso interno.
	 */
	public function updateRequestStatus($oData)
	{
		// Comprobaciones previas
		if (!isset($oData->authentication)) {
			throw new \Exception('tag authentication required');
		}
		if (!isset($oData->request)) {
			throw new \Exception('tag request required');
		}

		// Transformacion a array
		$vAuth = $this->objectTree2array($oData->authentication);
		$vReq = $this->objectTree2array($oData->request);
		$vSign = null;
		if (isset($oData->signature)) {
			$vSign = $this->objectTree2array($oData->signature);
		}

		// Interpretacion en clases del composer
		$oAuth = authentication::fromSoap($vAuth);
		$oReq = request::fromSoap($vReq);
		$oSign = null;
		if (!is_null($vSign)) {
			$oSign = signature::fromSoap($vSign);
		}

		// Invocacin de la funcion de Callback
		$return = call_user_func($this->fnCallback, $oAuth, $oReq, $oSign);
		if (is_bool($return)) {
			return array('result' => $return);
		}
		if ($return instanceof \SoapFault) {
			return $return;
		}
	}


	/**
	 * Crea y devuelve un SOAPFault adaptado a los requisitos/especificacion del WS.
	 * Este SOAPFault puede devolverse como resultado de la operacin en caso de error.
	 *
	 * @access	public
	 * @param  	string		$identifier	Identificador del error.
	 * @param  	string		$description	Descripcion del error.
	 * @return	\SOAPFault	Instancia de la excepcion (SOAPFault).
	 */
	public static function createExceptionInfo($identifier, $description) {
		$encIden = utf8_encode($identifier);
		$encDesc = utf8_encode($description);

		$array_details = array(
			'identifier' => $encIden,
			'description' => $encDesc
		);
		return new \SoapFault("Server", "[$encIden] $encDesc", null, $array_details, 'pfirmaException');
	}

	/**
	 * Trata de averiguar si se estn sirviendo las eticiones por HTTP o por HTTPS
	 * @return boolean
	 */
	public static function isSecure()
	{
		$isSecure = false;
		if (
			(isset($_SERVER['HTTPS'])
				&& ((strtolower($_SERVER['HTTPS']) == 'on') || $_SERVER['HTTPS'] == '1'))
			)
		{
			$isSecure = true;
		} elseif (
			(!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https')
			|| (!empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] == 'on')
		)
		{
			$isSecure = true;
		}
		return $isSecure;
	}//isSecure()


}

?>