<?php
namespace WSCOMUN\DGT\CONDUCTORVEHICULOS;

use Exception;
use SoapVar;
use ArrayObject;
use stdClass;


const unbounded = 'unbounded';


class objSolicitudTransmision
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';

	/**
	 * @var String
	 * Nif del Emisor
	 */
	private $nifEmisor = null;

	/**
	 * @var String
	 * Nombre o razn social del emisor
	 */
	private $nombreEmisor = null;

	/**
	 * @var String
	 * Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $codProcedimiento = null;

	/**
	 * @var String
	 * Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $nombreProcedimiento = null;

	/**
	 * @var String
	 * Nombre completo del empleado pblico que realiza la solicitud.
	 */
	private $nombreCompletoFuncionario = null;

	/**
	 * @var String
	 * NIF del empleado pblico que realiza la solicitud.
	 */
	private $nifFuncionario = null;

	/**
	 * @var String
	 * Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 */
	private $tipoDocumentacion = null;

	/**
	 * @var String
	 * Nmero de documento segn el <TipoDocumentacion>
	 */
	private $documentacion = null;

	/**
	 * @var String
	 * Nombre completo del titular de la solicitud
	 */
	private $nombreCompleto = null;

	/**
	 * @var String
	 * Nombre del titular de la solicitud
	 */
	private $nombre = null;

	/**
	 * @var String
	 * Primer Apellido del titular de la solicitud
	 */
	private $apellido1 = null;

	/**
	 * @var String
	 * Segundo Apellido del titular de la solicitud
	 */
	private $apellido2 = null;

	/**
	 * @var String
	 * NIF del organismo
	 */
	private $identificadorSolicitante = null;

	/**
	 * @var String
	 * Nombre o razn social del organismo
	 */
	private $nombreSolicitante = null;

	/**
	 * @var String
	 * Nombre de la Unidad Tramitadora que realiza la peticin
	 */
	private $unidadTramitadora = null;

	/**
	 * @var String
	 * Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 */
	private $finalidad = null;

	/**
	 * @var String
	 * Valores admitidos: Si, Ley
	 */
	private $consentimiento = null;

	/**
	 * @var String
	 * Identificador del Expediente que justifica la consulta.
	 */
	private $idExpediente = null;

	/**
	 * @var DatosEspecificos
	 * Datos especficos de la peticion
	 */
	private $oEspecifico = null;


	/**
	 * Establece los datos del organismo emisor que ofrece el servicio.
	 *
	 * @access	public
	 * @param String $nif Nif del Emisor
	 * @param String $nombre Nombre o razn social del emisor
	 */
	public function setEmisor($nif, $nombre) {
		$this->nifEmisor = $nif;
		$this->nombreEmisor = $nombre;
	}

	/**
	 * Establece los datos del procedimiento que autoriza la consulta.
	 *
	 * @access	public
	 * @param String $codigo Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 * @param String $nombre Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	public function setProcedimiento($codigo, $nombre) {
		$this->codProcedimiento = $codigo;
		$this->nombreProcedimiento = $nombre;
	}

	/**
	 * Establece los datos del empleado pblico que realiza la solicitud.
	 *
	 * @access	public
	 * @param String $nombreCompleto Nombre completo del empleado pblico que realiza la solicitud.
	 * @param String $nif NIF del empleado pblico que realiza la solicitud.
	 */
	public function setFuncionario($nombreCompleto, $nif) {
		$this->nombreCompletoFuncionario = $nombreCompleto;
		$this->nifFuncionario = $nif;
	}

	/**
	 * Establece los datos del ciudadano sobre el que se va a realizar la consulta.
	 *
	 * @access	public
	 * @param String $tipoDocumentacion Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 * @param String $documentacion Nmero de documento segn el tipo de documentacin indicado.
	 * @param String $nombreCompleto Nombre completo del titular de la solicitud
	 * @param String $nombre Nombre del titular de la solicitud
	 * @param String $apellido1 Primer Apellido del titular de la solicitud
	 * @param String $apellido2 Segundo Apellido del titular de la solicitud
	 */
	public function setTitular($tipoDocumentacion, $documentacion, $nombreCompleto = null, $nombre = null, $apellido1 = null, $apellido2 = null) {
		$this->tipoDocumentacion = $tipoDocumentacion;
		$this->documentacion = $documentacion;
		$this->nombreCompleto = $nombreCompleto;
		$this->nombre = $nombre;
		$this->apellido1 = $apellido1;
		$this->apellido2 = $apellido2;
	}

	/**
	 * Establece los datos del solicitante de la transmisin, as como la finalidad del mismo.
	 *
	 * @access	public
	 * @param String $identificadorSolicitante NIF del organismo solicitante
	 * @param String $nombreSolicitante Nombre o razn social del organismo solicitante
	 * @param String $consentimiento Valores admitidos: Si, Ley
	 * @param String $finalidad Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 * @param String $unidadTramitadora Nombre de la Unidad Tramitadora que realiza la peticin
	 * @param String $idExpediente Identificador del Expediente que justifica la consulta.
	 */
	public function setSolicitante($identificadorSolicitante, $nombreSolicitante, $consentimiento, $finalidad, $unidadTramitadora = null, $idExpediente = null) {
		$this->identificadorSolicitante = $identificadorSolicitante;
		$this->nombreSolicitante = $nombreSolicitante;
		$this->consentimiento = $consentimiento;
		$this->finalidad = $finalidad;
		$this->unidadTramitadora = $unidadTramitadora;
		$this->idExpediente = $idExpediente;
	}


	/**
	 * Establece los datos especificos de la peticin.
	 *
	 * @access	public
	 * @param DatosEspecificos $oEspecifico Datos especficos de la consulta
	 */
	public function setEspecifico($oEspecifico) {
		$this->oEspecifico = $oEspecifico;
	}


	/**
	 * Devuelve una copia del objeto, que mantiene los datos generales de la peticin: Emisor, procedimiento, funcionario, titular y solicitante
	 *
	 * @access	public
	 * @return	objSolicitudTransmision	Nueva instancia con los datos copiados
	 */
	public function duplicarCabecera() {
		$oClon = new objSolicitudTransmision();
		$oClon->setEmisor($this->nifEmisor, $this->nombreEmisor);
		$oClon->setProcedimiento($this->codProcedimiento, $this->nombreProcedimiento);
		$oClon->setFuncionario($this->nombreCompletoFuncionario, $this->nifFuncionario);
		$oClon->setTitular($this->tipoDocumentacion, $this->documentacion, $this->nombreCompleto, $this->nombre, $this->apellido1, $this->apellido2);
		$oClon->setSolicitante($this->identificadorSolicitante, $this->nombreSolicitante, $this->consentimiento, $this->finalidad, $this->unidadTramitadora, $this->idExpediente);

		return $oClon;
	}


	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @access 	public
	 * @param string $IdPeticion Identificador de la peticin
	 * @param string $CodigoCertificado Cdigo del certificado del servicio que solicita la peticion
	 * @param string $numParcial Subidentificador de la peticin. Cuando se suministra, se concatena al identificador de la peticion.
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 */
	public function toSoap($IdPeticion, $CodigoCertificado, $numParcial = null)
	{
		$IdSolicitud = $IdPeticion;
		if (!is_null($numParcial)) {
			$IdSolicitud = $IdPeticion . '_' . $numParcial;
		}

		// $CodigoCertificado debera ser auto-generado
		// IdentificadorSolicitante = (Sugerido) CODxxxxxx
		// Consentimiento = Si | Ley
		// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

		// Emisor
		$EmisorWSRequest = new ArrayObject();
		$EmisorWSRequest->append(new SoapVar($this->nifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_PET));
		$EmisorWSRequest->append(new SoapVar($this->nombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_PET));

		// Procedimiento
		$ProcedimientoWSRequest = new ArrayObject();
		$ProcedimientoWSRequest->append(new SoapVar($this->codProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_PET));
		$ProcedimientoWSRequest->append(new SoapVar($this->nombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_PET));

		// Funcionario
		$FuncionarioWSRequest = new ArrayObject();
		$FuncionarioWSRequest->append(new SoapVar($this->nombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_PET));
		$FuncionarioWSRequest->append(new SoapVar($this->nifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_PET));

		// Solicitante
		$SolicitanteWSRequest = new ArrayObject();
		$SolicitanteWSRequest->append(new SoapVar($this->identificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->nombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_PET));
		if (!is_null($this->unidadTramitadora)) {
			$SolicitanteWSRequest->append(new SoapVar($this->unidadTramitadora, XSD_STRING, null, null,'UnidadTramitadora', self::$NAMESPACE_PET));
		}
		$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_PET));
		if (!is_null($this->idExpediente)) {
			$SolicitanteWSRequest->append(new SoapVar($this->idExpediente, XSD_STRING, null, null,'IdExpediente', self::$NAMESPACE_PET));
		}

		// Titular
		$TitularWSRequest = new ArrayObject();
		$TitularWSRequest->append(new SoapVar($this->tipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_PET));
		$TitularWSRequest->append(new SoapVar($this->documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_PET));
		if (!is_null($this->nombreCompleto)) {
			$TitularWSRequest->append(new SoapVar($this->nombreCompleto, XSD_STRING, null, null,'NombreCompleto', self::$NAMESPACE_PET));
		}
		if (!is_null($this->nombre)) {
			$TitularWSRequest->append(new SoapVar($this->nombre, XSD_STRING, null, null,'Nombre', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido1)) {
			$TitularWSRequest->append(new SoapVar($this->apellido1, XSD_STRING, null, null,'Apellido1', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido2)) {
			$TitularWSRequest->append(new SoapVar($this->apellido2, XSD_STRING, null, null,'Apellido2', self::$NAMESPACE_PET));
		}

		// Transmision
		$TransmisionWSRequest = new ArrayObject();
		$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_PET));
		$TransmisionWSRequest->append(new SoapVar($IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosGenericosWSRequest = new ArrayObject();
		$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_PET));

		// SolicitudTransmision
		$SolicitudTransmisionWSRequest = new ArrayObject();
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_PET));


		if (!is_null($this->oEspecifico)) {
			$datosEspecificosSoapVar = $this->oEspecifico->toSoap('DatosEspecificos', self::$NAMESPACE_ESP);
			$SolicitudTransmisionWSRequest->append($datosEspecificosSoapVar);
		}


		// Devuelve la solicitud ya generada
		return new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_PET);
	}

}


class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
		//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
			//var_dump($childData);
			//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
			//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

		//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
				//				var_dump($vChildData);die;
			}
		}

		//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
					//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
					//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
					//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		 var_dump($parentTag);
		 var_dump($vData);
		 var_dump($fieldName);
		 var_dump($type);
		 var_dump($namespace);
		 var_dump($minOccurs);
		 var_dump($maxOccurs);

		 die("FAIL!!!");
		 */

		return true;
	}



	static public function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	static public function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}


class DatosEspecificos extends SoapObject {


    /**
     * @var Retorno Propiedad de navegacion entre objetos SOAP
     * name="Retorno" type="Retorno"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_retorno = null;
    private $_hasRetorno = false;
    public function setRetorno($value) {
        $this->_retorno = $value;
        $this->_hasRetorno = ($value !== null);
    }
    public function hasRetorno() {
        return $this->_hasRetorno;
    }
    public function getRetorno() {
        return $this->_retorno;
    }


    /**
     *
     * Devuelve una instancia de la clase DatosEspecificos con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DatosEspecificos 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DatosEspecificos();
        if (!isset($vData['Retorno'])) {
            throw new Exception('El parametro Retorno es obligatorio');
        }
        if (isset($vData['Retorno'])) {

            $newClass = Retorno::fromSoap($vData['Retorno']);
            $newItem->setRetorno($newClass);
        }

        return $newItem;
    }

    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();

        $this->__doChild($myLevel, $this->_retorno, 'Retorno', SOAP_ENC_OBJECT, $namespace, 1, 1, false);

        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Retorno extends SoapObject {


    /**
     * @var Estado Propiedad de navegacion entre objetos SOAP
     * name="Estado" type="Estado"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_estado = null;
    private $_hasEstado = false;
    public function setEstado($value) {
        $this->_estado = $value;
        $this->_hasEstado = ($value !== null);
    }
    public function hasEstado() {
        return $this->_hasEstado;
    }
    public function getEstado() {
        return $this->_estado;
    }


    /**
     * @var ListaVehiculos Propiedad de navegacion entre objetos SOAP
     * name="ListaVehiculos" type="ListaVehiculos"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_listaVehiculos = null;
    private $_hasListaVehiculos = false;
    public function setListaVehiculos($value) {
        $this->_listaVehiculos = $value;
        $this->_hasListaVehiculos = ($value !== null);
    }
    public function hasListaVehiculos() {
        return $this->_hasListaVehiculos;
    }
    public function getListaVehiculos() {
        return $this->_listaVehiculos;
    }


    /**
     *
     * Devuelve una instancia de la clase Retorno con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Retorno 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Retorno();
        if (!isset($vData['Estado'])) {
            throw new Exception('El parametro Estado es obligatorio');
        }
        if (isset($vData['Estado'])) {

            $newClass = Estado::fromSoap($vData['Estado']);
            $newItem->setEstado($newClass);
        }
        if (isset($vData['ListaVehiculos'])) {

            $newClass = ListaVehiculos::fromSoap($vData['ListaVehiculos']);
            $newItem->setListaVehiculos($newClass);
        }

        return $newItem;
    }

    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();

        $this->__doChild($myLevel, $this->_estado, 'Estado', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
        $this->__doChild($myLevel, $this->_listaVehiculos, 'ListaVehiculos', SOAP_ENC_OBJECT, $namespace, 0, 1, false);

        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Estado extends SoapObject {


    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="CodigoEstado" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_codigoEstado = null;
    private $_hasCodigoEstado = false;
    public function setCodigoEstado($value) {
        $this->_codigoEstado = $value;
        $this->_hasCodigoEstado = ($value !== null);
    }
    public function hasCodigoEstado() {
        return $this->_hasCodigoEstado;
    }
    public function getCodigoEstado() {
        return $this->_codigoEstado;
    }


    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="CodigoEstadoSecundario" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_codigoEstadoSecundario = null;
    private $_hasCodigoEstadoSecundario = false;
    public function setCodigoEstadoSecundario($value) {
        $this->_codigoEstadoSecundario = $value;
        $this->_hasCodigoEstadoSecundario = ($value !== null);
    }
    public function hasCodigoEstadoSecundario() {
        return $this->_hasCodigoEstadoSecundario;
    }
    public function getCodigoEstadoSecundario() {
        return $this->_codigoEstadoSecundario;
    }


    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Literal" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_literal = null;
    private $_hasLiteral = false;
    public function setLiteral($value) {
        $this->_literal = $value;
        $this->_hasLiteral = ($value !== null);
    }
    public function hasLiteral() {
        return $this->_hasLiteral;
    }
    public function getLiteral() {
        return $this->_literal;
    }


    /**
     *
     * Devuelve una instancia de la clase Estado con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Estado 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Estado();
        if (!isset($vData['CodigoEstado'])) {
            throw new Exception('El parametro CodigoEstado es obligatorio');
        }
        if (isset($vData['CodigoEstado'])) {

            $newItem->setCodigoEstado($vData['CodigoEstado']);
        }
        if (isset($vData['CodigoEstadoSecundario'])) {

            $newItem->setCodigoEstadoSecundario($vData['CodigoEstadoSecundario']);
        }
        if (!isset($vData['Literal'])) {
            throw new Exception('El parametro Literal es obligatorio');
        }
        if (isset($vData['Literal'])) {

            $newItem->setLiteral($vData['Literal']);
        }

        return $newItem;
    }

    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();

        $this->__doChild($myLevel, $this->_codigoEstado, 'CodigoEstado', 101, $namespace, 1, 1, false);
        $this->__doChild($myLevel, $this->_codigoEstadoSecundario, 'CodigoEstadoSecundario', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_literal, 'Literal', 101, $namespace, 1, 1, false);

        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class ListaVehiculos extends SoapObject {

    /**
     * @var Vehiculo Propiedad de navegacion entre objetos SOAP
     * name="Vehiculo" type="Vehiculo"[COMPLEXTYPE] minOccurs="1" maxOccurs="unbounded" nillable="false"
     */
    private $_vehiculo = array();
    private $_hasVehiculo = false;
    public function replaceArrayVehiculo($value) {
        $this->_vehiculo = $value;
        $this->_hasVehiculo = (isset($this->_vehiculo) && !empty($this->_vehiculo));
    }
    public function retrieveArrayVehiculo() {
        return $this->_vehiculo;
    }
    public function addVehiculo($value) {
        array_push($this->_vehiculo, $value);
        $this->_hasVehiculo = (isset($this->_vehiculo) && !empty($this->_vehiculo));
    }
    public function hasVehiculo() {
        return $this->_hasVehiculo;
    }
    public function getVehiculo($index) {
        return $this->_vehiculo[$index];
    }
    public function countVehiculo() {
        return count($this->_vehiculo);
    }


    /**
     *
     * Devuelve una instancia de la clase ListaVehiculos con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	ListaVehiculos 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new ListaVehiculos();
        if (!isset($vData['Vehiculo'])) {
            throw new Exception('El parametro Vehiculo es obligatorio');
        }
        if (isset($vData['Vehiculo']) && !empty($vData['Vehiculo'])) {
            if (SoapObject::is_assoc($vData['Vehiculo'])) {

                // Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
                $newClass = Vehiculo::fromSoap($vData['Vehiculo']);
                $newItem->addVehiculo($newClass);
            } else {

                foreach ($vData['Vehiculo'] as $oVar) {
                    $newClass = Vehiculo::fromSoap($oVar);
                    $newItem->addVehiculo($newClass);
                }
            }
        }

        return $newItem;
    }

    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();

        $this->__doChild($myLevel, $this->_vehiculo, 'Vehiculo', SOAP_ENC_OBJECT, $namespace, 1, unbounded, false);

        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Vehiculo extends SoapObject {


    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Matricula" type="Matricula"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_matricula = null;
    private $_hasMatricula = false;
    public function setMatricula($value) {
        $this->_matricula = $value;
        $this->_hasMatricula = ($value !== null);
    }
    public function hasMatricula() {
        return $this->_hasMatricula;
    }
    public function getMatricula() {
        return $this->_matricula;
    }


    /**
     *
     * Devuelve una instancia de la clase Vehiculo con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Vehiculo 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Vehiculo();
        if (!isset($vData['Matricula'])) {
            throw new Exception('El parametro Matricula es obligatorio');
        }
        if (isset($vData['Matricula'])) {

            $newItem->setMatricula($vData['Matricula']);
        }

        return $newItem;
    }

    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();

        $this->__doChild($myLevel, $this->_matricula, 'Matricula', 101, $namespace, 1, 1, false);

        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

?>