<?php
namespace WSCOMUN\DGT\DATOSVEHICULO;

use Exception;
use SoapVar;
use DateTime;
use ArrayObject;
use stdClass;

const unbounded = 'unbounded';

class objSolicitudTransmision
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';

	/**
	 * @var String
	 * Nif del Emisor
	 */
	private $nifEmisor = null;

	/**
	 * @var String
	 * Nombre o razn social del emisor
	 */
	private $nombreEmisor = null;

	/**
	 * @var String
	 * Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $codProcedimiento = null;

	/**
	 * @var String
	 * Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	private $nombreProcedimiento = null;

	/**
	 * @var String
	 * Nombre completo del empleado pblico que realiza la solicitud.
	 */
	private $nombreCompletoFuncionario = null;

	/**
	 * @var String
	 * NIF del empleado pblico que realiza la solicitud.
	 */
	private $nifFuncionario = null;

	/**
	 * @var String
	 * Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 */
	private $tipoDocumentacion = null;

	/**
	 * @var String
	 * Nmero de documento segn el <TipoDocumentacion>
	 */
	private $documentacion = null;

	/**
	 * @var String
	 * Nombre completo del titular de la solicitud
	 */
	private $nombreCompleto = null;

	/**
	 * @var String
	 * Nombre del titular de la solicitud
	 */
	private $nombre = null;

	/**
	 * @var String
	 * Primer Apellido del titular de la solicitud
	 */
	private $apellido1 = null;

	/**
	 * @var String
	 * Segundo Apellido del titular de la solicitud
	 */
	private $apellido2 = null;

	/**
	 * @var String
	 * NIF del organismo
	 */
	private $identificadorSolicitante = null;

	/**
	 * @var String
	 * Nombre o razn social del organismo
	 */
	private $nombreSolicitante = null;

	/**
	 * @var String
	 * Nombre de la Unidad Tramitadora que realiza la peticin
	 */
	private $unidadTramitadora = null;

	/**
	 * @var String
	 * Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 */
	private $finalidad = null;

	/**
	 * @var String
	 * Valores admitidos: Si, Ley
	 */
	private $consentimiento = null;

	/**
	 * @var String
	 * Identificador del Expediente que justifica la consulta.
	 */
	private $idExpediente = null;

	/**
	 * @var DatosEspecificos
	 * Datos especficos de la peticion
	 */
	private $oEspecifico = null;


	/**
	 * Establece los datos del organismo emisor que ofrece el servicio.
	 *
	 * @access	public
	 * @param String $nif Nif del Emisor
	 * @param String $nombre Nombre o razn social del emisor
	 */
	public function setEmisor($nif, $nombre) {
		$this->nifEmisor = $nif;
		$this->nombreEmisor = $nombre;
	}

	/**
	 * Establece los datos del procedimiento que autoriza la consulta.
	 *
	 * @access	public
	 * @param String $codigo Cdigo del Procedimiento que autoriza al usuario a realizar la consulta
	 * @param String $nombre Nombre del Procedimiento que autoriza al usuario a realizar la consulta
	 */
	public function setProcedimiento($codigo, $nombre) {
		$this->codProcedimiento = $codigo;
		$this->nombreProcedimiento = $nombre;
	}

	/**
	 * Establece los datos del empleado pblico que realiza la solicitud.
	 *
	 * @access	public
	 * @param String $nombreCompleto Nombre completo del empleado pblico que realiza la solicitud.
	 * @param String $nif NIF del empleado pblico que realiza la solicitud.
	 */
	public function setFuncionario($nombreCompleto, $nif) {
		$this->nombreCompletoFuncionario = $nombreCompleto;
		$this->nifFuncionario = $nif;
	}

	/**
	 * Establece los datos del ciudadano sobre el que se va a realizar la consulta.
	 *
	 * @access	public
	 * @param String $tipoDocumentacion Documentacin identificativa del titular. Puede ser: NIF, NIE, CIF
	 * @param String $documentacion Nmero de documento segn el tipo de documentacin indicado.
	 * @param String $nombreCompleto Nombre completo del titular de la solicitud
	 * @param String $nombre Nombre del titular de la solicitud
	 * @param String $apellido1 Primer Apellido del titular de la solicitud
	 * @param String $apellido2 Segundo Apellido del titular de la solicitud
	 */
	public function setTitular($tipoDocumentacion, $documentacion, $nombreCompleto = null, $nombre = null, $apellido1 = null, $apellido2 = null) {
		$this->tipoDocumentacion = $tipoDocumentacion;
		$this->documentacion = $documentacion;
		$this->nombreCompleto = $nombreCompleto;
		$this->nombre = $nombre;
		$this->apellido1 = $apellido1;
		$this->apellido2 = $apellido2;
	}

	/**
	 * Establece los datos del solicitante de la transmisin, as como la finalidad del mismo.
	 *
	 * @access	public
	 * @param String $identificadorSolicitante NIF del organismo solicitante
	 * @param String $nombreSolicitante Nombre o razn social del organismo solicitante
	 * @param String $consentimiento Valores admitidos: Si, Ley
	 * @param String $finalidad Contiene el motivo o causa por la que se necesita realizar la consulta de los datos.
	 * @param String $unidadTramitadora Nombre de la Unidad Tramitadora que realiza la peticin
	 * @param String $idExpediente Identificador del Expediente que justifica la consulta.
	 */
	public function setSolicitante($identificadorSolicitante, $nombreSolicitante, $consentimiento, $finalidad, $unidadTramitadora = null, $idExpediente = null) {
		$this->identificadorSolicitante = $identificadorSolicitante;
		$this->nombreSolicitante = $nombreSolicitante;
		$this->consentimiento = $consentimiento;
		$this->finalidad = $finalidad;
		$this->unidadTramitadora = $unidadTramitadora;
		$this->idExpediente = $idExpediente;
	}


	/**
	 * Establece los datos especificos de la peticin. Se recomienda usar los mtodos setMatricula, setBastidor y setNIVE en su lugar.
	 *
	 * @access	public
	 * @param DatosEspecificos $oEspecifico Datos especficos de la consulta
	 */
	public function setEspecifico($oEspecifico) {
		$this->oEspecifico = $oEspecifico;
	}


	/**
	 * Devuelve una copia del objeto, que mantiene los datos generales de la peticin: Emisor, procedimiento, funcionario, titular y solicitante
	 *
	 * @access	public
	 * @return	objSolicitudTransmision	Nueva instancia con los datos copiados
	 */
	public function duplicarCabecera() {
		$oClon = new objSolicitudTransmision();
		$oClon->setEmisor($this->nifEmisor, $this->nombreEmisor);
		$oClon->setProcedimiento($this->codProcedimiento, $this->nombreProcedimiento);
		$oClon->setFuncionario($this->nombreCompletoFuncionario, $this->nifFuncionario);
		$oClon->setTitular($this->tipoDocumentacion, $this->documentacion, $this->nombreCompleto, $this->nombre, $this->apellido1, $this->apellido2);
		$oClon->setSolicitante($this->identificadorSolicitante, $this->nombreSolicitante, $this->consentimiento, $this->finalidad, $this->unidadTramitadora, $this->idExpediente);

		return $oClon;
	}


	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @access 	public
	 * @param string $IdPeticion Identificador de la peticin
	 * @param string $CodigoCertificado Cdigo del certificado del servicio que solicita la peticion
	 * @param string $numParcial Subidentificador de la peticin. Cuando se suministra, se concatena al identificador de la peticion.
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 */
	public function toSoap($IdPeticion, $CodigoCertificado, $numParcial = null)
	{
		$IdSolicitud = $IdPeticion;
		if (!is_null($numParcial)) {
			$IdSolicitud = $IdPeticion . '_' . $numParcial;
		}

		// $CodigoCertificado debera ser auto-generado
		// IdentificadorSolicitante = (Sugerido) CODxxxxxx
		// Consentimiento = Si | Ley
		// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

		// Emisor
		$EmisorWSRequest = new ArrayObject();
		$EmisorWSRequest->append(new SoapVar($this->nifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_PET));
		$EmisorWSRequest->append(new SoapVar($this->nombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_PET));

		// Procedimiento
		$ProcedimientoWSRequest = new ArrayObject();
		$ProcedimientoWSRequest->append(new SoapVar($this->codProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_PET));
		$ProcedimientoWSRequest->append(new SoapVar($this->nombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_PET));

		// Funcionario
		$FuncionarioWSRequest = new ArrayObject();
		$FuncionarioWSRequest->append(new SoapVar($this->nombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_PET));
		$FuncionarioWSRequest->append(new SoapVar($this->nifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_PET));

		// Solicitante
		$SolicitanteWSRequest = new ArrayObject();
		$SolicitanteWSRequest->append(new SoapVar($this->identificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->nombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_PET));
		if (!is_null($this->unidadTramitadora)) {
			$SolicitanteWSRequest->append(new SoapVar($this->unidadTramitadora, XSD_STRING, null, null,'UnidadTramitadora', self::$NAMESPACE_PET));
		}
		$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_PET));
		if (!is_null($this->idExpediente)) {
			$SolicitanteWSRequest->append(new SoapVar($this->idExpediente, XSD_STRING, null, null,'IdExpediente', self::$NAMESPACE_PET));
		}

		// Titular
		$TitularWSRequest = new ArrayObject();
		$TitularWSRequest->append(new SoapVar($this->tipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_PET));
		$TitularWSRequest->append(new SoapVar($this->documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_PET));
		if (!is_null($this->nombreCompleto)) {
			$TitularWSRequest->append(new SoapVar($this->nombreCompleto, XSD_STRING, null, null,'NombreCompleto', self::$NAMESPACE_PET));
		}
		if (!is_null($this->nombre)) {
			$TitularWSRequest->append(new SoapVar($this->nombre, XSD_STRING, null, null,'Nombre', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido1)) {
			$TitularWSRequest->append(new SoapVar($this->apellido1, XSD_STRING, null, null,'Apellido1', self::$NAMESPACE_PET));
		}
		if (!is_null($this->apellido2)) {
			$TitularWSRequest->append(new SoapVar($this->apellido2, XSD_STRING, null, null,'Apellido2', self::$NAMESPACE_PET));
		}

		// Transmision
		$TransmisionWSRequest = new ArrayObject();
		$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_PET));
		$TransmisionWSRequest->append(new SoapVar($IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosGenericosWSRequest = new ArrayObject();
		$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_PET));

		// SolicitudTransmision
		$SolicitudTransmisionWSRequest = new ArrayObject();
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_PET));

		// DatosEspecificos
		if (!is_null($this->oEspecifico)) {
			$datosEspecificosSoapVar = $this->oEspecifico->toSoap('DatosEspecificos', self::$NAMESPACE_ESP);
			$SolicitudTransmisionWSRequest->append($datosEspecificosSoapVar);
		}


		// Devuelve la solicitud ya generada
		return new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_PET);
	}


	/**
	 *
	 * Configura la parte especfica de la peticion para consultar una matricula.
	 *
	 * @access 	public
	 * @param string $valor Matricula a consultar
	 */
	public function ConsultarMatricula($valor) {
		$oCon = new Consulta();
		$oCon->setMatricula($valor);

		$this->oEspecifico = new DatosEspecificos();
		$this->oEspecifico->setConsulta($oCon);
	}


	/**
	 *
	 * Configura la parte especfica de la peticion para consultar mediante el bastidor.
	 *
	 * @access 	public
	 * @param string $valor Bastidor a consultar
	 */
	public function ConsultarBastidor($valor) {
		$oCon = new Consulta();
		$oCon->setBastidor($valor);

		$this->oEspecifico = new DatosEspecificos();
		$this->oEspecifico->setConsulta($oCon);
	}


	/**
	 *
	 * Configura la parte especfica de la peticion para consultar mediante la tarjeta de la ITV electronica (NIVE).
	 *
	 * @access 	public
	 * @param string $valor NIVE a consultar
	 */
	public function ConsultarNIVE($valor) {
		$oCon = new Consulta();
		$oCon->setNIVE($valor);

		$this->oEspecifico = new DatosEspecificos();
		$this->oEspecifico->setConsulta($oCon);
	}

}


class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
		//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
			//var_dump($childData);
			//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
			//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

		//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs, $isChoice)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if (($minOccurs > 0) && (!$isChoice)) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
				//				var_dump($vChildData);die;
			}
		}

		//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
					//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
					//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
					//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		 var_dump($parentTag);
		 var_dump($vData);
		 var_dump($fieldName);
		 var_dump($type);
		 var_dump($namespace);
		 var_dump($minOccurs);
		 var_dump($maxOccurs);

		 die("FAIL!!!");
		 */

		return true;
	}



	static public function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	static public function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}


class DatosEspecificos extends SoapObject {
    // MODE: choice
    
    /**
     * @var Consulta Propiedad de navegacion entre objetos SOAP
     * name="Consulta" type="Consulta"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_consulta = null;
    private $_hasConsulta = false;
    public function setConsulta($value) {
        $this->_consulta = $value;
        $this->_hasConsulta = ($value !== null);
    }
    public function hasConsulta() {
        return $this->_hasConsulta;
    }
    public function getConsulta() {
        return $this->_consulta;
    }
    
    
    /**
     * @var Retorno Propiedad de navegacion entre objetos SOAP
     * name="Retorno" type="Retorno"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_retorno = null;
    private $_hasRetorno = false;
    public function setRetorno($value) {
        $this->_retorno = $value;
        $this->_hasRetorno = ($value !== null);
    }
    public function hasRetorno() {
        return $this->_hasRetorno;
    }
    public function getRetorno() {
        return $this->_retorno;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DatosEspecificos con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DatosEspecificos 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DatosEspecificos();
        $choiceSetted = false;
        
        if (isset($vData['Consulta'])) {
            if ($choiceSetted) {
                throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
            }
            $choiceSetted = true;
            
            $newClass = Consulta::fromSoap($vData['Consulta']);
            $newItem->setConsulta($newClass);
        }
        if (isset($vData['Retorno'])) {
            if ($choiceSetted) {
                throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
            }
            $choiceSetted = true;
            
            $newClass = Retorno::fromSoap($vData['Retorno']);
            $newItem->setRetorno($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_consulta, 'Consulta', SOAP_ENC_OBJECT, $namespace, 1, 1, true);
        $this->__doChild($myLevel, $this->_retorno, 'Retorno', SOAP_ENC_OBJECT, $namespace, 1, 1, true);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Consulta extends SoapObject {
    // MODE: choice
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Matricula" type="Matricula"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_matricula = null;
    private $_hasMatricula = false;
    public function setMatricula($value) {
        $this->_matricula = $value;
        $this->_hasMatricula = ($value !== null);
    }
    public function hasMatricula() {
        return $this->_hasMatricula;
    }
    public function getMatricula() {
        return $this->_matricula;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Bastidor" type="Bastidor"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_bastidor = null;
    private $_hasBastidor = false;
    public function setBastidor($value) {
        $this->_bastidor = $value;
        $this->_hasBastidor = ($value !== null);
    }
    public function hasBastidor() {
        return $this->_hasBastidor;
    }
    public function getBastidor() {
        return $this->_bastidor;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="NIVE" type="NIVE"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_nIVE = null;
    private $_hasNIVE = false;
    public function setNIVE($value) {
        $this->_nIVE = $value;
        $this->_hasNIVE = ($value !== null);
    }
    public function hasNIVE() {
        return $this->_hasNIVE;
    }
    public function getNIVE() {
        return $this->_nIVE;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Consulta con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Consulta 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Consulta();
        $choiceSetted = false;
        
        if (isset($vData['Matricula'])) {
            if ($choiceSetted) {
                throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
            }
            $choiceSetted = true;
            
            $newItem->setMatricula($vData['Matricula']);
        }
        if (isset($vData['Bastidor'])) {
            if ($choiceSetted) {
                throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
            }
            $choiceSetted = true;
            
            $newItem->setBastidor($vData['Bastidor']);
        }
        if (isset($vData['NIVE'])) {
            if ($choiceSetted) {
                throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
            }
            $choiceSetted = true;
            
            $newItem->setNIVE($vData['NIVE']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_matricula, 'Matricula', 101, $namespace, 1, 1, true);
        $this->__doChild($myLevel, $this->_bastidor, 'Bastidor', 101, $namespace, 1, 1, true);
        $this->__doChild($myLevel, $this->_nIVE, 'NIVE', 101, $namespace, 1, 1, true);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Retorno extends SoapObject {
    
    
    /**
     * @var Estado Propiedad de navegacion entre objetos SOAP
     * name="Estado" type="Estado"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_estado = null;
    private $_hasEstado = false;
    public function setEstado($value) {
        $this->_estado = $value;
        $this->_hasEstado = ($value !== null);
    }
    public function hasEstado() {
        return $this->_hasEstado;
    }
    public function getEstado() {
        return $this->_estado;
    }
    
    
    /**
     * @var Consulta Propiedad de navegacion entre objetos SOAP
     * name="Consulta" type="Consulta"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_consulta = null;
    private $_hasConsulta = false;
    public function setConsulta($value) {
        $this->_consulta = $value;
        $this->_hasConsulta = ($value !== null);
    }
    public function hasConsulta() {
        return $this->_hasConsulta;
    }
    public function getConsulta() {
        return $this->_consulta;
    }
    
    
    /**
     * @var DatosVehiculo Propiedad de navegacion entre objetos SOAP
     * name="DatosVehiculo" type="DatosVehiculo"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_datosVehiculo = null;
    private $_hasDatosVehiculo = false;
    public function setDatosVehiculo($value) {
        $this->_datosVehiculo = $value;
        $this->_hasDatosVehiculo = ($value !== null);
    }
    public function hasDatosVehiculo() {
        return $this->_hasDatosVehiculo;
    }
    public function getDatosVehiculo() {
        return $this->_datosVehiculo;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Retorno con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Retorno 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Retorno();
        if (!isset($vData['Estado'])) {
            throw new Exception('El parametro Estado es obligatorio');
        }
        if (isset($vData['Estado'])) {
            
            $newClass = Estado::fromSoap($vData['Estado']);
            $newItem->setEstado($newClass);
        }
        if (!isset($vData['Consulta'])) {
            throw new Exception('El parametro Consulta es obligatorio');
        }
        if (isset($vData['Consulta'])) {
            
            $newClass = Consulta::fromSoap($vData['Consulta']);
            $newItem->setConsulta($newClass);
        }
        if (isset($vData['DatosVehiculo'])) {
            
            $newClass = DatosVehiculo::fromSoap($vData['DatosVehiculo']);
            $newItem->setDatosVehiculo($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_estado, 'Estado', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
        $this->__doChild($myLevel, $this->_consulta, 'Consulta', SOAP_ENC_OBJECT, $namespace, 1, 1, false);
        $this->__doChild($myLevel, $this->_datosVehiculo, 'DatosVehiculo', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Estado extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="CodigoEstado" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_codigoEstado = null;
    private $_hasCodigoEstado = false;
    public function setCodigoEstado($value) {
        $this->_codigoEstado = $value;
        $this->_hasCodigoEstado = ($value !== null);
    }
    public function hasCodigoEstado() {
        return $this->_hasCodigoEstado;
    }
    public function getCodigoEstado() {
        return $this->_codigoEstado;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="CodigoEstadoSecundario" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_codigoEstadoSecundario = null;
    private $_hasCodigoEstadoSecundario = false;
    public function setCodigoEstadoSecundario($value) {
        $this->_codigoEstadoSecundario = $value;
        $this->_hasCodigoEstadoSecundario = ($value !== null);
    }
    public function hasCodigoEstadoSecundario() {
        return $this->_hasCodigoEstadoSecundario;
    }
    public function getCodigoEstadoSecundario() {
        return $this->_codigoEstadoSecundario;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Literal" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
     */
    private $_literal = null;
    private $_hasLiteral = false;
    public function setLiteral($value) {
        $this->_literal = $value;
        $this->_hasLiteral = ($value !== null);
    }
    public function hasLiteral() {
        return $this->_hasLiteral;
    }
    public function getLiteral() {
        return $this->_literal;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Estado con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Estado 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Estado();
        if (!isset($vData['CodigoEstado'])) {
            throw new Exception('El parametro CodigoEstado es obligatorio');
        }
        if (isset($vData['CodigoEstado'])) {
            
            $newItem->setCodigoEstado($vData['CodigoEstado']);
        }
        if (isset($vData['CodigoEstadoSecundario'])) {
            
            $newItem->setCodigoEstadoSecundario($vData['CodigoEstadoSecundario']);
        }
        if (!isset($vData['Literal'])) {
            throw new Exception('El parametro Literal es obligatorio');
        }
        if (isset($vData['Literal'])) {
            
            $newItem->setLiteral($vData['Literal']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_codigoEstado, 'CodigoEstado', 101, $namespace, 1, 1, false);
        $this->__doChild($myLevel, $this->_codigoEstadoSecundario, 'CodigoEstadoSecundario', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_literal, 'Literal', 101, $namespace, 1, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DatosVehiculo extends SoapObject {
    
    
    /**
     * @var DatosGenerales Propiedad de navegacion entre objetos SOAP
     * name="DatosGenerales" type="DatosGenerales"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_datosGenerales = null;
    private $_hasDatosGenerales = false;
    public function setDatosGenerales($value) {
        $this->_datosGenerales = $value;
        $this->_hasDatosGenerales = ($value !== null);
    }
    public function hasDatosGenerales() {
        return $this->_hasDatosGenerales;
    }
    public function getDatosGenerales() {
        return $this->_datosGenerales;
    }
    
    
    /**
     * @var DatosTecnicos Propiedad de navegacion entre objetos SOAP
     * name="DatosTecnicos" type="DatosTecnicos"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_datosTecnicos = null;
    private $_hasDatosTecnicos = false;
    public function setDatosTecnicos($value) {
        $this->_datosTecnicos = $value;
        $this->_hasDatosTecnicos = ($value !== null);
    }
    public function hasDatosTecnicos() {
        return $this->_hasDatosTecnicos;
    }
    public function getDatosTecnicos() {
        return $this->_datosTecnicos;
    }
    
    
    /**
     * @var DatosTramites Propiedad de navegacion entre objetos SOAP
     * name="DatosTramites" type="DatosTramites"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_datosTramites = null;
    private $_hasDatosTramites = false;
    public function setDatosTramites($value) {
        $this->_datosTramites = $value;
        $this->_hasDatosTramites = ($value !== null);
    }
    public function hasDatosTramites() {
        return $this->_hasDatosTramites;
    }
    public function getDatosTramites() {
        return $this->_datosTramites;
    }
    
    
    /**
     * @var DatosAdministrativos Propiedad de navegacion entre objetos SOAP
     * name="DatosAdministrativos" type="DatosAdministrativos"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_datosAdministrativos = null;
    private $_hasDatosAdministrativos = false;
    public function setDatosAdministrativos($value) {
        $this->_datosAdministrativos = $value;
        $this->_hasDatosAdministrativos = ($value !== null);
    }
    public function hasDatosAdministrativos() {
        return $this->_hasDatosAdministrativos;
    }
    public function getDatosAdministrativos() {
        return $this->_datosAdministrativos;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DatosVehiculo con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DatosVehiculo 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DatosVehiculo();
        if (isset($vData['DatosGenerales'])) {
            
            $newClass = DatosGenerales::fromSoap($vData['DatosGenerales']);
            $newItem->setDatosGenerales($newClass);
        }
        if (isset($vData['DatosTecnicos'])) {
            
            $newClass = DatosTecnicos::fromSoap($vData['DatosTecnicos']);
            $newItem->setDatosTecnicos($newClass);
        }
        if (isset($vData['DatosTramites'])) {
            
            $newClass = DatosTramites::fromSoap($vData['DatosTramites']);
            $newItem->setDatosTramites($newClass);
        }
        if (isset($vData['DatosAdministrativos'])) {
            
            $newClass = DatosAdministrativos::fromSoap($vData['DatosAdministrativos']);
            $newItem->setDatosAdministrativos($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_datosGenerales, 'DatosGenerales', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_datosTecnicos, 'DatosTecnicos', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_datosTramites, 'DatosTramites', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_datosAdministrativos, 'DatosAdministrativos', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DatosGenerales extends SoapObject {
    
    
    /**
     * @var DescripcionVehiculo Propiedad de navegacion entre objetos SOAP
     * name="DescripcionVehiculo" type="DescripcionVehiculo"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_descripcionVehiculo = null;
    private $_hasDescripcionVehiculo = false;
    public function setDescripcionVehiculo($value) {
        $this->_descripcionVehiculo = $value;
        $this->_hasDescripcionVehiculo = ($value !== null);
    }
    public function hasDescripcionVehiculo() {
        return $this->_hasDescripcionVehiculo;
    }
    public function getDescripcionVehiculo() {
        return $this->_descripcionVehiculo;
    }
    
    
    /**
     * @var DomicilioVehiculoDGT Propiedad de navegacion entre objetos SOAP
     * name="DomicilioVehiculoDGT" type="DomicilioVehiculoDGT"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_domicilioVehiculoDGT = null;
    private $_hasDomicilioVehiculoDGT = false;
    public function setDomicilioVehiculoDGT($value) {
        $this->_domicilioVehiculoDGT = $value;
        $this->_hasDomicilioVehiculoDGT = ($value !== null);
    }
    public function hasDomicilioVehiculoDGT() {
        return $this->_hasDomicilioVehiculoDGT;
    }
    public function getDomicilioVehiculoDGT() {
        return $this->_domicilioVehiculoDGT;
    }
    
    
    /**
     * @var DomicilioVehiculoINE Propiedad de navegacion entre objetos SOAP
     * name="DomicilioVehiculoINE" type="DomicilioVehiculoINE"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_domicilioVehiculoINE = null;
    private $_hasDomicilioVehiculoINE = false;
    public function setDomicilioVehiculoINE($value) {
        $this->_domicilioVehiculoINE = $value;
        $this->_hasDomicilioVehiculoINE = ($value !== null);
    }
    public function hasDomicilioVehiculoINE() {
        return $this->_hasDomicilioVehiculoINE;
    }
    public function getDomicilioVehiculoINE() {
        return $this->_domicilioVehiculoINE;
    }
    
    
    /**
     * @var Indicadores Propiedad de navegacion entre objetos SOAP
     * name="Indicadores" type="Indicadores"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_indicadores = null;
    private $_hasIndicadores = false;
    public function setIndicadores($value) {
        $this->_indicadores = $value;
        $this->_hasIndicadores = ($value !== null);
    }
    public function hasIndicadores() {
        return $this->_hasIndicadores;
    }
    public function getIndicadores() {
        return $this->_indicadores;
    }
    
    
    /**
     * @var Matriculacion Propiedad de navegacion entre objetos SOAP
     * name="Matriculacion" type="Matriculacion"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_matriculacion = null;
    private $_hasMatriculacion = false;
    public function setMatriculacion($value) {
        $this->_matriculacion = $value;
        $this->_hasMatriculacion = ($value !== null);
    }
    public function hasMatriculacion() {
        return $this->_hasMatriculacion;
    }
    public function getMatriculacion() {
        return $this->_matriculacion;
    }
    
    
    /**
     * @var Titular Propiedad de navegacion entre objetos SOAP
     * name="Titular" type="Titular"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_titular = null;
    private $_hasTitular = false;
    public function setTitular($value) {
        $this->_titular = $value;
        $this->_hasTitular = ($value !== null);
    }
    public function hasTitular() {
        return $this->_hasTitular;
    }
    public function getTitular() {
        return $this->_titular;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DatosGenerales con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DatosGenerales 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DatosGenerales();
        if (isset($vData['DescripcionVehiculo'])) {
            
            $newClass = DescripcionVehiculo::fromSoap($vData['DescripcionVehiculo']);
            $newItem->setDescripcionVehiculo($newClass);
        }
        if (isset($vData['DomicilioVehiculoDGT'])) {
            
            $newClass = DomicilioVehiculoDGT::fromSoap($vData['DomicilioVehiculoDGT']);
            $newItem->setDomicilioVehiculoDGT($newClass);
        }
        if (isset($vData['DomicilioVehiculoINE'])) {
            
            $newClass = DomicilioVehiculoINE::fromSoap($vData['DomicilioVehiculoINE']);
            $newItem->setDomicilioVehiculoINE($newClass);
        }
        if (isset($vData['Indicadores'])) {
            
            $newClass = Indicadores::fromSoap($vData['Indicadores']);
            $newItem->setIndicadores($newClass);
        }
        if (isset($vData['Matriculacion'])) {
            
            $newClass = Matriculacion::fromSoap($vData['Matriculacion']);
            $newItem->setMatriculacion($newClass);
        }
        if (isset($vData['Titular'])) {
            
            $newClass = Titular::fromSoap($vData['Titular']);
            $newItem->setTitular($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_descripcionVehiculo, 'DescripcionVehiculo', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_domicilioVehiculoDGT, 'DomicilioVehiculoDGT', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_domicilioVehiculoINE, 'DomicilioVehiculoINE', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_indicadores, 'Indicadores', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_matriculacion, 'Matriculacion', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_titular, 'Titular', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DescripcionVehiculo extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Bastidor" type="Bastidor"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_bastidor = null;
    private $_hasBastidor = false;
    public function setBastidor($value) {
        $this->_bastidor = $value;
        $this->_hasBastidor = ($value !== null);
    }
    public function hasBastidor() {
        return $this->_hasBastidor;
    }
    public function getBastidor() {
        return $this->_bastidor;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="NIVE" type="NIVE"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_nIVE = null;
    private $_hasNIVE = false;
    public function setNIVE($value) {
        $this->_nIVE = $value;
        $this->_hasNIVE = ($value !== null);
    }
    public function hasNIVE() {
        return $this->_hasNIVE;
    }
    public function getNIVE() {
        return $this->_nIVE;
    }
    
    
    /**
     * @var Marca Propiedad de navegacion entre objetos SOAP
     * name="Marca" type="Marca"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_marca = null;
    private $_hasMarca = false;
    public function setMarca($value) {
        $this->_marca = $value;
        $this->_hasMarca = ($value !== null);
    }
    public function hasMarca() {
        return $this->_hasMarca;
    }
    public function getMarca() {
        return $this->_marca;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Modelo" type="Modelo"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_modelo = null;
    private $_hasModelo = false;
    public function setModelo($value) {
        $this->_modelo = $value;
        $this->_hasModelo = ($value !== null);
    }
    public function hasModelo() {
        return $this->_hasModelo;
    }
    public function getModelo() {
        return $this->_modelo;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DescripcionVehiculo con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DescripcionVehiculo 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DescripcionVehiculo();
        if (isset($vData['Bastidor'])) {
            
            $newItem->setBastidor($vData['Bastidor']);
        }
        if (isset($vData['NIVE'])) {
            
            $newItem->setNIVE($vData['NIVE']);
        }
        if (isset($vData['Marca'])) {
            
            $newClass = Marca::fromSoap($vData['Marca']);
            $newItem->setMarca($newClass);
        }
        if (isset($vData['Modelo'])) {
            
            $newItem->setModelo($vData['Modelo']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_bastidor, 'Bastidor', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_nIVE, 'NIVE', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_marca, 'Marca', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_modelo, 'Modelo', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Marca extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Codigo" type="Codigo"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_codigo = null;
    private $_hasCodigo = false;
    public function setCodigo($value) {
        $this->_codigo = $value;
        $this->_hasCodigo = ($value !== null);
    }
    public function hasCodigo() {
        return $this->_hasCodigo;
    }
    public function getCodigo() {
        return $this->_codigo;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Descripcion" type="Descripcion"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_descripcion = null;
    private $_hasDescripcion = false;
    public function setDescripcion($value) {
        $this->_descripcion = $value;
        $this->_hasDescripcion = ($value !== null);
    }
    public function hasDescripcion() {
        return $this->_hasDescripcion;
    }
    public function getDescripcion() {
        return $this->_descripcion;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Marca con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Marca 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Marca();
        if (isset($vData['Codigo'])) {
            
            $newItem->setCodigo($vData['Codigo']);
        }
        if (isset($vData['Descripcion'])) {
            
            $newItem->setDescripcion($vData['Descripcion']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_descripcion, 'Descripcion', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DomicilioVehiculoDGT extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Municipio" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_municipio = null;
    private $_hasMunicipio = false;
    public function setMunicipio($value) {
        $this->_municipio = $value;
        $this->_hasMunicipio = ($value !== null);
    }
    public function hasMunicipio() {
        return $this->_hasMunicipio;
    }
    public function getMunicipio() {
        return $this->_municipio;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DomicilioVehiculoDGT con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DomicilioVehiculoDGT 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DomicilioVehiculoDGT();
        if (isset($vData['Municipio'])) {
            
            $newItem->setMunicipio($vData['Municipio']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_municipio, 'Municipio', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DomicilioVehiculoINE extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Municipio" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_municipio = null;
    private $_hasMunicipio = false;
    public function setMunicipio($value) {
        $this->_municipio = $value;
        $this->_hasMunicipio = ($value !== null);
    }
    public function hasMunicipio() {
        return $this->_hasMunicipio;
    }
    public function getMunicipio() {
        return $this->_municipio;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DomicilioVehiculoINE con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DomicilioVehiculoINE 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DomicilioVehiculoINE();
        if (isset($vData['Municipio'])) {
            
            $newItem->setMunicipio($vData['Municipio']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_municipio, 'Municipio', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DomicilioDGT extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="NombreVia" type="NombreVia"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_nombreVia = null;
    private $_hasNombreVia = false;
    public function setNombreVia($value) {
        $this->_nombreVia = $value;
        $this->_hasNombreVia = ($value !== null);
    }
    public function hasNombreVia() {
        return $this->_hasNombreVia;
    }
    public function getNombreVia() {
        return $this->_nombreVia;
    }
    
    
    /**
     * @var Provincia Propiedad de navegacion entre objetos SOAP
     * name="Provincia" type="Provincia"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_provincia = null;
    private $_hasProvincia = false;
    public function setProvincia($value) {
        $this->_provincia = $value;
        $this->_hasProvincia = ($value !== null);
    }
    public function hasProvincia() {
        return $this->_hasProvincia;
    }
    public function getProvincia() {
        return $this->_provincia;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Municipio" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_municipio = null;
    private $_hasMunicipio = false;
    public function setMunicipio($value) {
        $this->_municipio = $value;
        $this->_hasMunicipio = ($value !== null);
    }
    public function hasMunicipio() {
        return $this->_hasMunicipio;
    }
    public function getMunicipio() {
        return $this->_municipio;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Localidad" type="Localidad"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_localidad = null;
    private $_hasLocalidad = false;
    public function setLocalidad($value) {
        $this->_localidad = $value;
        $this->_hasLocalidad = ($value !== null);
    }
    public function hasLocalidad() {
        return $this->_hasLocalidad;
    }
    public function getLocalidad() {
        return $this->_localidad;
    }
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="CodigoPostal" type="CodigoPostal"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_codigoPostal = null;
    private $_hasCodigoPostal = false;
    public function setCodigoPostal($value) {
        $this->_codigoPostal = $value;
        $this->_hasCodigoPostal = ($value !== null);
    }
    public function hasCodigoPostal() {
        return $this->_hasCodigoPostal;
    }
    public function getCodigoPostal() {
        return $this->_codigoPostal;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DomicilioDGT con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DomicilioDGT 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DomicilioDGT();
        if (isset($vData['NombreVia'])) {
            
            $newItem->setNombreVia($vData['NombreVia']);
        }
        if (isset($vData['Provincia'])) {
            
            $newClass = Provincia::fromSoap($vData['Provincia']);
            $newItem->setProvincia($newClass);
        }
        if (isset($vData['Municipio'])) {
            
            $newItem->setMunicipio($vData['Municipio']);
        }
        if (isset($vData['Localidad'])) {
            
            $newItem->setLocalidad($vData['Localidad']);
        }
        if (isset($vData['CodigoPostal'])) {
            
            $newItem->setCodigoPostal($vData['CodigoPostal']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_nombreVia, 'NombreVia', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_provincia, 'Provincia', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_municipio, 'Municipio', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_localidad, 'Localidad', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_codigoPostal, 'CodigoPostal', 135, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DomicilioINE extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="TipoVia" type="TipoVia"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_tipoVia = null;
    private $_hasTipoVia = false;
    public function setTipoVia($value) {
        $this->_tipoVia = $value;
        $this->_hasTipoVia = ($value !== null);
    }
    public function hasTipoVia() {
        return $this->_hasTipoVia;
    }
    public function getTipoVia() {
        return $this->_tipoVia;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="NombreVia" type="NombreVia"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_nombreVia = null;
    private $_hasNombreVia = false;
    public function setNombreVia($value) {
        $this->_nombreVia = $value;
        $this->_hasNombreVia = ($value !== null);
    }
    public function hasNombreVia() {
        return $this->_hasNombreVia;
    }
    public function getNombreVia() {
        return $this->_nombreVia;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="NumeroVia" type="NumeroVia"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_numeroVia = null;
    private $_hasNumeroVia = false;
    public function setNumeroVia($value) {
        $this->_numeroVia = $value;
        $this->_hasNumeroVia = ($value !== null);
    }
    public function hasNumeroVia() {
        return $this->_hasNumeroVia;
    }
    public function getNumeroVia() {
        return $this->_numeroVia;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Portal" type="Portal"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_portal = null;
    private $_hasPortal = false;
    public function setPortal($value) {
        $this->_portal = $value;
        $this->_hasPortal = ($value !== null);
    }
    public function hasPortal() {
        return $this->_hasPortal;
    }
    public function getPortal() {
        return $this->_portal;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Bloque" type="Bloque"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_bloque = null;
    private $_hasBloque = false;
    public function setBloque($value) {
        $this->_bloque = $value;
        $this->_hasBloque = ($value !== null);
    }
    public function hasBloque() {
        return $this->_hasBloque;
    }
    public function getBloque() {
        return $this->_bloque;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Escalera" type="Escalera"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_escalera = null;
    private $_hasEscalera = false;
    public function setEscalera($value) {
        $this->_escalera = $value;
        $this->_hasEscalera = ($value !== null);
    }
    public function hasEscalera() {
        return $this->_hasEscalera;
    }
    public function getEscalera() {
        return $this->_escalera;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Planta" type="Planta"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_planta = null;
    private $_hasPlanta = false;
    public function setPlanta($value) {
        $this->_planta = $value;
        $this->_hasPlanta = ($value !== null);
    }
    public function hasPlanta() {
        return $this->_hasPlanta;
    }
    public function getPlanta() {
        return $this->_planta;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Puerta" type="Puerta"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_puerta = null;
    private $_hasPuerta = false;
    public function setPuerta($value) {
        $this->_puerta = $value;
        $this->_hasPuerta = ($value !== null);
    }
    public function hasPuerta() {
        return $this->_hasPuerta;
    }
    public function getPuerta() {
        return $this->_puerta;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Kilometro" type="Kilometro"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_kilometro = null;
    private $_hasKilometro = false;
    public function setKilometro($value) {
        $this->_kilometro = $value;
        $this->_hasKilometro = ($value !== null);
    }
    public function hasKilometro() {
        return $this->_hasKilometro;
    }
    public function getKilometro() {
        return $this->_kilometro;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Hectometro" type="Hectometro"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_hectometro = null;
    private $_hasHectometro = false;
    public function setHectometro($value) {
        $this->_hectometro = $value;
        $this->_hasHectometro = ($value !== null);
    }
    public function hasHectometro() {
        return $this->_hasHectometro;
    }
    public function getHectometro() {
        return $this->_hectometro;
    }
    
    
    /**
     * @var Provincia Propiedad de navegacion entre objetos SOAP
     * name="Provincia" type="Provincia"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_provincia = null;
    private $_hasProvincia = false;
    public function setProvincia($value) {
        $this->_provincia = $value;
        $this->_hasProvincia = ($value !== null);
    }
    public function hasProvincia() {
        return $this->_hasProvincia;
    }
    public function getProvincia() {
        return $this->_provincia;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Municipio" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_municipio = null;
    private $_hasMunicipio = false;
    public function setMunicipio($value) {
        $this->_municipio = $value;
        $this->_hasMunicipio = ($value !== null);
    }
    public function hasMunicipio() {
        return $this->_hasMunicipio;
    }
    public function getMunicipio() {
        return $this->_municipio;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Localidad" type="Localidad"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_localidad = null;
    private $_hasLocalidad = false;
    public function setLocalidad($value) {
        $this->_localidad = $value;
        $this->_hasLocalidad = ($value !== null);
    }
    public function hasLocalidad() {
        return $this->_hasLocalidad;
    }
    public function getLocalidad() {
        return $this->_localidad;
    }
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="CodigoPostal" type="CodigoPostal"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_codigoPostal = null;
    private $_hasCodigoPostal = false;
    public function setCodigoPostal($value) {
        $this->_codigoPostal = $value;
        $this->_hasCodigoPostal = ($value !== null);
    }
    public function hasCodigoPostal() {
        return $this->_hasCodigoPostal;
    }
    public function getCodigoPostal() {
        return $this->_codigoPostal;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DomicilioINE con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DomicilioINE 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DomicilioINE();
        if (isset($vData['TipoVia'])) {
            
            $newItem->setTipoVia($vData['TipoVia']);
        }
        if (isset($vData['NombreVia'])) {
            
            $newItem->setNombreVia($vData['NombreVia']);
        }
        if (isset($vData['NumeroVia'])) {
            
            $newItem->setNumeroVia($vData['NumeroVia']);
        }
        if (isset($vData['Portal'])) {
            
            $newItem->setPortal($vData['Portal']);
        }
        if (isset($vData['Bloque'])) {
            
            $newItem->setBloque($vData['Bloque']);
        }
        if (isset($vData['Escalera'])) {
            
            $newItem->setEscalera($vData['Escalera']);
        }
        if (isset($vData['Planta'])) {
            
            $newItem->setPlanta($vData['Planta']);
        }
        if (isset($vData['Puerta'])) {
            
            $newItem->setPuerta($vData['Puerta']);
        }
        if (isset($vData['Kilometro'])) {
            
            $newItem->setKilometro($vData['Kilometro']);
        }
        if (isset($vData['Hectometro'])) {
            
            $newItem->setHectometro($vData['Hectometro']);
        }
        if (isset($vData['Provincia'])) {
            
            $newClass = Provincia::fromSoap($vData['Provincia']);
            $newItem->setProvincia($newClass);
        }
        if (isset($vData['Municipio'])) {
            
            $newItem->setMunicipio($vData['Municipio']);
        }
        if (isset($vData['Localidad'])) {
            
            $newItem->setLocalidad($vData['Localidad']);
        }
        if (isset($vData['CodigoPostal'])) {
            
            $newItem->setCodigoPostal($vData['CodigoPostal']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_tipoVia, 'TipoVia', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_nombreVia, 'NombreVia', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_numeroVia, 'NumeroVia', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_portal, 'Portal', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_bloque, 'Bloque', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_escalera, 'Escalera', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_planta, 'Planta', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_puerta, 'Puerta', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_kilometro, 'Kilometro', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_hectometro, 'Hectometro', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_provincia, 'Provincia', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_municipio, 'Municipio', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_localidad, 'Localidad', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_codigoPostal, 'CodigoPostal', 135, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Indicadores extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="BajaTemporal" type="BajaTemporal"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_bajaTemporal = null;
    private $_hasBajaTemporal = false;
    public function setBajaTemporal($value) {
        $this->_bajaTemporal = $value;
        $this->_hasBajaTemporal = ($value !== null);
    }
    public function hasBajaTemporal() {
        return $this->_hasBajaTemporal;
    }
    public function getBajaTemporal() {
        return $this->_bajaTemporal;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="BajaDefinitiva" type="BajaDefinitiva"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_bajaDefinitiva = null;
    private $_hasBajaDefinitiva = false;
    public function setBajaDefinitiva($value) {
        $this->_bajaDefinitiva = $value;
        $this->_hasBajaDefinitiva = ($value !== null);
    }
    public function hasBajaDefinitiva() {
        return $this->_hasBajaDefinitiva;
    }
    public function getBajaDefinitiva() {
        return $this->_bajaDefinitiva;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Indicadores con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Indicadores 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Indicadores();
        if (isset($vData['BajaTemporal'])) {
            
            $newItem->setBajaTemporal($vData['BajaTemporal']);
        }
        if (isset($vData['BajaDefinitiva'])) {
            
            $newItem->setBajaDefinitiva($vData['BajaDefinitiva']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_bajaTemporal, 'BajaTemporal', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_bajaDefinitiva, 'BajaDefinitiva', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Matriculacion extends SoapObject {
    
    
    /**
     * @var datetime Propiedad de navegacion entre objetos SOAP
     * name="FechaMatriculacion" type="FechaMatriculacion"[109] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_fechaMatriculacion = null;
    private $_hasFechaMatriculacion = false;
    public function setFechaMatriculacion($value) {
        $this->_fechaMatriculacion = $value;
        $this->_hasFechaMatriculacion = ($value !== null);
    }
    public function hasFechaMatriculacion() {
        return $this->_hasFechaMatriculacion;
    }
    public function getFechaMatriculacion() {
        return $this->_fechaMatriculacion;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Matricula" type="Matricula"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_matricula = null;
    private $_hasMatricula = false;
    public function setMatricula($value) {
        $this->_matricula = $value;
        $this->_hasMatricula = ($value !== null);
    }
    public function hasMatricula() {
        return $this->_hasMatricula;
    }
    public function getMatricula() {
        return $this->_matricula;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Matriculacion con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Matriculacion 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Matriculacion();
        if (isset($vData['FechaMatriculacion'])) {
            
            $newItem->setFechaMatriculacion($vData['FechaMatriculacion']);
        }
        if (isset($vData['Matricula'])) {
            
            $newItem->setMatricula($vData['Matricula']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_fechaMatriculacion, 'FechaMatriculacion', 109, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_matricula, 'Matricula', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Titular extends SoapObject {
    
    
    /**
     * @var DomicilioDGT Propiedad de navegacion entre objetos SOAP
     * name="DomicilioDGT" type="DomicilioDGT"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_domicilioDGT = null;
    private $_hasDomicilioDGT = false;
    public function setDomicilioDGT($value) {
        $this->_domicilioDGT = $value;
        $this->_hasDomicilioDGT = ($value !== null);
    }
    public function hasDomicilioDGT() {
        return $this->_hasDomicilioDGT;
    }
    public function getDomicilioDGT() {
        return $this->_domicilioDGT;
    }
    
    
    /**
     * @var DomicilioINE Propiedad de navegacion entre objetos SOAP
     * name="DomicilioINE" type="DomicilioINE"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_domicilioINE = null;
    private $_hasDomicilioINE = false;
    public function setDomicilioINE($value) {
        $this->_domicilioINE = $value;
        $this->_hasDomicilioINE = ($value !== null);
    }
    public function hasDomicilioINE() {
        return $this->_hasDomicilioINE;
    }
    public function getDomicilioINE() {
        return $this->_domicilioINE;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Titular con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Titular 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Titular();
        if (isset($vData['DomicilioDGT'])) {
            
            $newClass = DomicilioDGT::fromSoap($vData['DomicilioDGT']);
            $newItem->setDomicilioDGT($newClass);
        }
        if (isset($vData['DomicilioINE'])) {
            
            $newClass = DomicilioINE::fromSoap($vData['DomicilioINE']);
            $newItem->setDomicilioINE($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_domicilioDGT, 'DomicilioDGT', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_domicilioINE, 'DomicilioINE', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DatosTecnicos extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="NivelEmisiones" type="NivelEmisiones"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_nivelEmisiones = null;
    private $_hasNivelEmisiones = false;
    public function setNivelEmisiones($value) {
        $this->_nivelEmisiones = $value;
        $this->_hasNivelEmisiones = ($value !== null);
    }
    public function hasNivelEmisiones() {
        return $this->_hasNivelEmisiones;
    }
    public function getNivelEmisiones() {
        return $this->_nivelEmisiones;
    }
    
    
    /**
     * @var Masas Propiedad de navegacion entre objetos SOAP
     * name="Masas" type="Masas"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_masas = null;
    private $_hasMasas = false;
    public function setMasas($value) {
        $this->_masas = $value;
        $this->_hasMasas = ($value !== null);
    }
    public function hasMasas() {
        return $this->_hasMasas;
    }
    public function getMasas() {
        return $this->_masas;
    }
    
    
    /**
     * @var Plazas Propiedad de navegacion entre objetos SOAP
     * name="Plazas" type="Plazas"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_plazas = null;
    private $_hasPlazas = false;
    public function setPlazas($value) {
        $this->_plazas = $value;
        $this->_hasPlazas = ($value !== null);
    }
    public function hasPlazas() {
        return $this->_hasPlazas;
    }
    public function getPlazas() {
        return $this->_plazas;
    }
    
    
    /**
     * @var Potencias Propiedad de navegacion entre objetos SOAP
     * name="Potencias" type="Potencias"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_potencias = null;
    private $_hasPotencias = false;
    public function setPotencias($value) {
        $this->_potencias = $value;
        $this->_hasPotencias = ($value !== null);
    }
    public function hasPotencias() {
        return $this->_hasPotencias;
    }
    public function getPotencias() {
        return $this->_potencias;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DatosTecnicos con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DatosTecnicos 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DatosTecnicos();
        if (isset($vData['NivelEmisiones'])) {
            
            $newItem->setNivelEmisiones($vData['NivelEmisiones']);
        }
        if (isset($vData['Masas'])) {
            
            $newClass = Masas::fromSoap($vData['Masas']);
            $newItem->setMasas($newClass);
        }
        if (isset($vData['Plazas'])) {
            
            $newClass = Plazas::fromSoap($vData['Plazas']);
            $newItem->setPlazas($newClass);
        }
        if (isset($vData['Potencias'])) {
            
            $newClass = Potencias::fromSoap($vData['Potencias']);
            $newItem->setPotencias($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_nivelEmisiones, 'NivelEmisiones', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_masas, 'Masas', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_plazas, 'Plazas', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_potencias, 'Potencias', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Masas extends SoapObject {
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="MasaMaximaTecnica" type="MasaMaximaTecnica"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_masaMaximaTecnica = null;
    private $_hasMasaMaximaTecnica = false;
    public function setMasaMaximaTecnica($value) {
        $this->_masaMaximaTecnica = $value;
        $this->_hasMasaMaximaTecnica = ($value !== null);
    }
    public function hasMasaMaximaTecnica() {
        return $this->_hasMasaMaximaTecnica;
    }
    public function getMasaMaximaTecnica() {
        return $this->_masaMaximaTecnica;
    }
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="MasaMaxima" type="MasaMaxima"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_masaMaxima = null;
    private $_hasMasaMaxima = false;
    public function setMasaMaxima($value) {
        $this->_masaMaxima = $value;
        $this->_hasMasaMaxima = ($value !== null);
    }
    public function hasMasaMaxima() {
        return $this->_hasMasaMaxima;
    }
    public function getMasaMaxima() {
        return $this->_masaMaxima;
    }
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="MasaServicio" type="MasaServicio"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_masaServicio = null;
    private $_hasMasaServicio = false;
    public function setMasaServicio($value) {
        $this->_masaServicio = $value;
        $this->_hasMasaServicio = ($value !== null);
    }
    public function hasMasaServicio() {
        return $this->_hasMasaServicio;
    }
    public function getMasaServicio() {
        return $this->_masaServicio;
    }
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="Tara" type="Tara"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_tara = null;
    private $_hasTara = false;
    public function setTara($value) {
        $this->_tara = $value;
        $this->_hasTara = ($value !== null);
    }
    public function hasTara() {
        return $this->_hasTara;
    }
    public function getTara() {
        return $this->_tara;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Masas con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Masas 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Masas();
        if (isset($vData['MasaMaximaTecnica'])) {
            
            $newItem->setMasaMaximaTecnica($vData['MasaMaximaTecnica']);
        }
        if (isset($vData['MasaMaxima'])) {
            
            $newItem->setMasaMaxima($vData['MasaMaxima']);
        }
        if (isset($vData['MasaServicio'])) {
            
            $newItem->setMasaServicio($vData['MasaServicio']);
        }
        if (isset($vData['Tara'])) {
            
            $newItem->setTara($vData['Tara']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_masaMaximaTecnica, 'MasaMaximaTecnica', 135, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_masaMaxima, 'MasaMaxima', 135, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_masaServicio, 'MasaServicio', 135, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_tara, 'Tara', 135, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Plazas extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Mixtas" type="Mixtas"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_mixtas = null;
    private $_hasMixtas = false;
    public function setMixtas($value) {
        $this->_mixtas = $value;
        $this->_hasMixtas = ($value !== null);
    }
    public function hasMixtas() {
        return $this->_hasMixtas;
    }
    public function getMixtas() {
        return $this->_mixtas;
    }
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="Normales" type="Normales"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_normales = null;
    private $_hasNormales = false;
    public function setNormales($value) {
        $this->_normales = $value;
        $this->_hasNormales = ($value !== null);
    }
    public function hasNormales() {
        return $this->_hasNormales;
    }
    public function getNormales() {
        return $this->_normales;
    }
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="NumeroPlazasPie" type="NumeroPlazasPie"[135] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_numeroPlazasPie = null;
    private $_hasNumeroPlazasPie = false;
    public function setNumeroPlazasPie($value) {
        $this->_numeroPlazasPie = $value;
        $this->_hasNumeroPlazasPie = ($value !== null);
    }
    public function hasNumeroPlazasPie() {
        return $this->_hasNumeroPlazasPie;
    }
    public function getNumeroPlazasPie() {
        return $this->_numeroPlazasPie;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Plazas con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Plazas 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Plazas();
        if (isset($vData['Mixtas'])) {
            
            $newItem->setMixtas($vData['Mixtas']);
        }
        if (isset($vData['Normales'])) {
            
            $newItem->setNormales($vData['Normales']);
        }
        if (isset($vData['NumeroPlazasPie'])) {
            
            $newItem->setNumeroPlazasPie($vData['NumeroPlazasPie']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_mixtas, 'Mixtas', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_normales, 'Normales', 135, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_numeroPlazasPie, 'NumeroPlazasPie', 135, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Potencias extends SoapObject {
    
    
    /**
     * @var double Propiedad de navegacion entre objetos SOAP
     * name="Cilindrada" type="Cilindrada"[104] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_cilindrada = null;
    private $_hasCilindrada = false;
    public function setCilindrada($value) {
        $this->_cilindrada = $value;
        $this->_hasCilindrada = ($value !== null);
    }
    public function hasCilindrada() {
        return $this->_hasCilindrada;
    }
    public function getCilindrada() {
        return $this->_cilindrada;
    }
    
    
    /**
     * @var double Propiedad de navegacion entre objetos SOAP
     * name="PotenciaFiscal" type="PotenciaFiscal"[104] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_potenciaFiscal = null;
    private $_hasPotenciaFiscal = false;
    public function setPotenciaFiscal($value) {
        $this->_potenciaFiscal = $value;
        $this->_hasPotenciaFiscal = ($value !== null);
    }
    public function hasPotenciaFiscal() {
        return $this->_hasPotenciaFiscal;
    }
    public function getPotenciaFiscal() {
        return $this->_potenciaFiscal;
    }
    
    
    /**
     * @var double Propiedad de navegacion entre objetos SOAP
     * name="PotenciaNetaMaxima" type="PotenciaNetaMaxima"[104] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_potenciaNetaMaxima = null;
    private $_hasPotenciaNetaMaxima = false;
    public function setPotenciaNetaMaxima($value) {
        $this->_potenciaNetaMaxima = $value;
        $this->_hasPotenciaNetaMaxima = ($value !== null);
    }
    public function hasPotenciaNetaMaxima() {
        return $this->_hasPotenciaNetaMaxima;
    }
    public function getPotenciaNetaMaxima() {
        return $this->_potenciaNetaMaxima;
    }
    
    
    /**
     * @var double Propiedad de navegacion entre objetos SOAP
     * name="RelacionPotenciaPeso" type="RelacionPotenciaPeso"[104] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_relacionPotenciaPeso = null;
    private $_hasRelacionPotenciaPeso = false;
    public function setRelacionPotenciaPeso($value) {
        $this->_relacionPotenciaPeso = $value;
        $this->_hasRelacionPotenciaPeso = ($value !== null);
    }
    public function hasRelacionPotenciaPeso() {
        return $this->_hasRelacionPotenciaPeso;
    }
    public function getRelacionPotenciaPeso() {
        return $this->_relacionPotenciaPeso;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Potencias con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Potencias 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Potencias();
        if (isset($vData['Cilindrada'])) {
            
            $newItem->setCilindrada($vData['Cilindrada']);
        }
        if (isset($vData['PotenciaFiscal'])) {
            
            $newItem->setPotenciaFiscal($vData['PotenciaFiscal']);
        }
        if (isset($vData['PotenciaNetaMaxima'])) {
            
            $newItem->setPotenciaNetaMaxima($vData['PotenciaNetaMaxima']);
        }
        if (isset($vData['RelacionPotenciaPeso'])) {
            
            $newItem->setRelacionPotenciaPeso($vData['RelacionPotenciaPeso']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_cilindrada, 'Cilindrada', 104, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_potenciaFiscal, 'PotenciaFiscal', 104, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_potenciaNetaMaxima, 'PotenciaNetaMaxima', 104, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_relacionPotenciaPeso, 'RelacionPotenciaPeso', 104, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DatosTramites extends SoapObject {
    
    
    /**
     * @var Baja Propiedad de navegacion entre objetos SOAP
     * name="Baja" type="Baja"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_baja = null;
    private $_hasBaja = false;
    public function setBaja($value) {
        $this->_baja = $value;
        $this->_hasBaja = ($value !== null);
    }
    public function hasBaja() {
        return $this->_hasBaja;
    }
    public function getBaja() {
        return $this->_baja;
    }
    
    
    /**
     * @var datetime Propiedad de navegacion entre objetos SOAP
     * name="FechaTransferencia" type="FechaTransferencia"[109] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_fechaTransferencia = null;
    private $_hasFechaTransferencia = false;
    public function setFechaTransferencia($value) {
        $this->_fechaTransferencia = $value;
        $this->_hasFechaTransferencia = ($value !== null);
    }
    public function hasFechaTransferencia() {
        return $this->_hasFechaTransferencia;
    }
    public function getFechaTransferencia() {
        return $this->_fechaTransferencia;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DatosTramites con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DatosTramites 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DatosTramites();
        if (isset($vData['Baja'])) {
            
            $newClass = Baja::fromSoap($vData['Baja']);
            $newItem->setBaja($newClass);
        }
        if (isset($vData['FechaTransferencia'])) {
            
            $newItem->setFechaTransferencia($vData['FechaTransferencia']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_baja, 'Baja', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_fechaTransferencia, 'FechaTransferencia', 109, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Baja extends SoapObject {
    
    
    /**
     * @var datetime Propiedad de navegacion entre objetos SOAP
     * name="FechaInicio" type="FechaInicio"[109] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_fechaInicio = null;
    private $_hasFechaInicio = false;
    public function setFechaInicio($value) {
        $this->_fechaInicio = $value;
        $this->_hasFechaInicio = ($value !== null);
    }
    public function hasFechaInicio() {
        return $this->_hasFechaInicio;
    }
    public function getFechaInicio() {
        return $this->_fechaInicio;
    }
    
    
    /**
     * @var datetime Propiedad de navegacion entre objetos SOAP
     * name="FechaFin" type="FechaFin"[109] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_fechaFin = null;
    private $_hasFechaFin = false;
    public function setFechaFin($value) {
        $this->_fechaFin = $value;
        $this->_hasFechaFin = ($value !== null);
    }
    public function hasFechaFin() {
        return $this->_hasFechaFin;
    }
    public function getFechaFin() {
        return $this->_fechaFin;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Baja con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Baja 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Baja();
        if (isset($vData['FechaInicio'])) {
            
            $newItem->setFechaInicio($vData['FechaInicio']);
        }
        if (isset($vData['FechaFin'])) {
            
            $newItem->setFechaFin($vData['FechaFin']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_fechaInicio, 'FechaInicio', 109, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_fechaFin, 'FechaFin', 109, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class DatosAdministrativos extends SoapObject {
    
    
    /**
     * @var ListaImpagos Propiedad de navegacion entre objetos SOAP
     * name="ListaImpagos" type="ListaImpagos"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_listaImpagos = null;
    private $_hasListaImpagos = false;
    public function setListaImpagos($value) {
        $this->_listaImpagos = $value;
        $this->_hasListaImpagos = ($value !== null);
    }
    public function hasListaImpagos() {
        return $this->_hasListaImpagos;
    }
    public function getListaImpagos() {
        return $this->_listaImpagos;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase DatosAdministrativos con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	DatosAdministrativos 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new DatosAdministrativos();
        if (isset($vData['ListaImpagos'])) {
            
            $newClass = ListaImpagos::fromSoap($vData['ListaImpagos']);
            $newItem->setListaImpagos($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_listaImpagos, 'ListaImpagos', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class ListaImpagos extends SoapObject {
    
    /**
     * @var Impago Propiedad de navegacion entre objetos SOAP
     * name="Impago" type="Impago"[COMPLEXTYPE] minOccurs="1" maxOccurs="unbounded" nillable="false"
     */
    private $_impago = array();
    private $_hasImpago = false;
    public function replaceArrayImpago($value) {
        $this->_impago = $value;
        $this->_hasImpago = (isset($this->_impago) && !empty($this->_impago));
    }
    public function retrieveArrayImpago() {
        return $this->_impago;
    }
    public function addImpago($value) {
        array_push($this->_impago, $value);
        $this->_hasImpago = (isset($this->_impago) && !empty($this->_impago));
    }
    public function hasImpago() {
        return $this->_hasImpago;
    }
    public function getImpago($index) {
        return $this->_impago[$index];
    }
    public function countImpago() {
        return count($this->_impago);
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase ListaImpagos con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	ListaImpagos 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new ListaImpagos();
        if (!isset($vData['Impago'])) {
            throw new Exception('El parametro Impago es obligatorio');
        }
        if (isset($vData['Impago']) && !empty($vData['Impago'])) {
            if (SoapObject::is_assoc($vData['Impago'])) {
                
                // Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
                $newClass = Impago::fromSoap($vData['Impago']);
                $newItem->addImpago($newClass);
            } else {
                
                foreach ($vData['Impago'] as $oVar) {
                    $newClass = Impago::fromSoap($oVar);
                    $newItem->addImpago($newClass);
                }
            }
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_impago, 'Impago', SOAP_ENC_OBJECT, $namespace, 1, unbounded, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Impago extends SoapObject {
    
    
    /**
     * @var integer Propiedad de navegacion entre objetos SOAP
     * name="AnioImpago" type="AnioImpago"[111] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_anioImpago = null;
    private $_hasAnioImpago = false;
    public function setAnioImpago($value) {
        $this->_anioImpago = $value;
        $this->_hasAnioImpago = ($value !== null);
    }
    public function hasAnioImpago() {
        return $this->_hasAnioImpago;
    }
    public function getAnioImpago() {
        return $this->_anioImpago;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Documentacion" type="Documentacion"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_documentacion = null;
    private $_hasDocumentacion = false;
    public function setDocumentacion($value) {
        $this->_documentacion = $value;
        $this->_hasDocumentacion = ($value !== null);
    }
    public function hasDocumentacion() {
        return $this->_hasDocumentacion;
    }
    public function getDocumentacion() {
        return $this->_documentacion;
    }
    
    
    /**
     * @var Provincia Propiedad de navegacion entre objetos SOAP
     * name="Provincia" type="Provincia"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_provincia = null;
    private $_hasProvincia = false;
    public function setProvincia($value) {
        $this->_provincia = $value;
        $this->_hasProvincia = ($value !== null);
    }
    public function hasProvincia() {
        return $this->_hasProvincia;
    }
    public function getProvincia() {
        return $this->_provincia;
    }
    
    
    /**
     * @var Municipio Propiedad de navegacion entre objetos SOAP
     * name="Municipio" type="Municipio"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_municipio = null;
    private $_hasMunicipio = false;
    public function setMunicipio($value) {
        $this->_municipio = $value;
        $this->_hasMunicipio = ($value !== null);
    }
    public function hasMunicipio() {
        return $this->_hasMunicipio;
    }
    public function getMunicipio() {
        return $this->_municipio;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Impago con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Impago 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Impago();
        if (isset($vData['AnioImpago'])) {
            
            $newItem->setAnioImpago($vData['AnioImpago']);
        }
        if (isset($vData['Documentacion'])) {
            
            $newItem->setDocumentacion($vData['Documentacion']);
        }
        if (isset($vData['Provincia'])) {
            
            $newClass = Provincia::fromSoap($vData['Provincia']);
            $newItem->setProvincia($newClass);
        }
        if (isset($vData['Municipio'])) {
            
            $newClass = Municipio::fromSoap($vData['Municipio']);
            $newItem->setMunicipio($newClass);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_anioImpago, 'AnioImpago', 111, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_documentacion, 'Documentacion', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_provincia, 'Provincia', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_municipio, 'Municipio', SOAP_ENC_OBJECT, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Municipio extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Codigo" type="Codigo"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_codigo = null;
    private $_hasCodigo = false;
    public function setCodigo($value) {
        $this->_codigo = $value;
        $this->_hasCodigo = ($value !== null);
    }
    public function hasCodigo() {
        return $this->_hasCodigo;
    }
    public function getCodigo() {
        return $this->_codigo;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Descripcion" type="Descripcion"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_descripcion = null;
    private $_hasDescripcion = false;
    public function setDescripcion($value) {
        $this->_descripcion = $value;
        $this->_hasDescripcion = ($value !== null);
    }
    public function hasDescripcion() {
        return $this->_hasDescripcion;
    }
    public function getDescripcion() {
        return $this->_descripcion;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Municipio con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Municipio 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Municipio();
        if (isset($vData['Codigo'])) {
            
            $newItem->setCodigo($vData['Codigo']);
        }
        if (isset($vData['Descripcion'])) {
            
            $newItem->setDescripcion($vData['Descripcion']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_descripcion, 'Descripcion', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

class Provincia extends SoapObject {
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Codigo" type="Codigo"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_codigo = null;
    private $_hasCodigo = false;
    public function setCodigo($value) {
        $this->_codigo = $value;
        $this->_hasCodigo = ($value !== null);
    }
    public function hasCodigo() {
        return $this->_hasCodigo;
    }
    public function getCodigo() {
        return $this->_codigo;
    }
    
    
    /**
     * @var string Propiedad de navegacion entre objetos SOAP
     * name="Descripcion" type="Descripcion"[101] minOccurs="0" maxOccurs="1" nillable="false"
     */
    private $_descripcion = null;
    private $_hasDescripcion = false;
    public function setDescripcion($value) {
        $this->_descripcion = $value;
        $this->_hasDescripcion = ($value !== null);
    }
    public function hasDescripcion() {
        return $this->_hasDescripcion;
    }
    public function getDescripcion() {
        return $this->_descripcion;
    }
    
    
    /**
     *
     * Devuelve una instancia de la clase Provincia con los datos suministrados.
     *
     * @param string $vData Array que contiene la informacin a instanciar
     * @return	Provincia 	Instancia que contiene los datos suministados
     * @access 	public
     */
    static public function fromSoap($vData) {
        $newItem = new Provincia();
        if (isset($vData['Codigo'])) {
            
            $newItem->setCodigo($vData['Codigo']);
        }
        if (isset($vData['Descripcion'])) {
            
            $newItem->setDescripcion($vData['Descripcion']);
        }
        
        return $newItem;
    }
    
    /**
     *
     * Convierte el objeto en su representacin SOAP.
     *
     * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
     * @param string $namespace Espacio de nombres del campo SOAP
     * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
     * @access 	public
     */
    public function toSoap($fieldName, $namespace) {
        $myLevel = new ArrayObject();
        
        $this->__doChild($myLevel, $this->_codigo, 'Codigo', 101, $namespace, 0, 1, false);
        $this->__doChild($myLevel, $this->_descripcion, 'Descripcion', 101, $namespace, 0, 1, false);
        
        //return $myLevel;
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    }
}

?>