<?php
namespace WSCOMUN\RTSOA;

use WSCMIME\WSCMimeParser;
use Exception;
use SoapClient;
use DOMDocument;
//use Exception;


/**
 * Paquetes para gestion MTOM
 */
require_once('ComposerRTSOA.php');
/**
 * Clase para la insercin y lectura de documetos en GDE SIN pasar por la PAI.
 * @author dpascual
 *
 */
class RTSOAClient
{

	const NS = 'http://services.v1.ws.web.mastin.tra.dgm.gva.es/';
	const TIMEOUT = 90;

	/**
	 * @var	$serviceParams	array	Parametros por defecto del cliente WS
	 */
	private $serviceParams = array ();

	/** @var string URL al WSDL de WS donde realizar las peticiones */
	private $wsURLWSDL;


	/**
	 * Construye un objeto
	 *
	 * @param string $wsURLWSDL URL del WSDL del WS donde realizar las peticiones
	 */
	public function __construct($wsURLWSDL)
	{
		$this->serviceParams = array (
				'soap_version' => SOAP_1_1
				,'stream_context' => stream_context_create (
					array (
						'ssl' => array (
							'verify_peer' => false,
							'verify_peer_name' => false,
							'allow_self_signed' => true
						)
						,'http'=>array (
							'user_agent' => 'WSSSoapClient',
							'timeout' => self::TIMEOUT
						)
						,'https' => array (
							'timeout' => self::TIMEOUT
						)
					)
				)
				,'user_agent' => 'WSSSoapClient'
				,'exceptions' => true
				,'trace' => 1
		);

		$this->wsURLWSDL = $wsURLWSDL;
	}


	private function getTipoRegistro($esRegistroEntrada) {
		if ($esRegistroEntrada) {
			return "E";
		}
		return "S";
	}
	private function codificarBooleano($valor) {
		if ($valor) {
			return "S";
		}
		return "N";
	}


	/**
	 * Realiza la peticin "lanzaDispatcher" al WS, tomando como parmetros las cadenas BASE64 de la peticion
	 * @param string $xmlEntrada Cadena con el contenido integro de la peticin
	 * @param string $vDocs	Array con el contenido de los documentos adjuntos a la peticion
	 * @return array Respuesta del WS a la peticion
	 */
	private function lanzaDispatcher($xmlEntrada, $vDocs)
	{
		try
		{
			// Instancia y configura el cliente SOAP
			$clienteWS = new \SoapClient($this->wsURLWSDL, $this->serviceParams);
			$lanzaDispatcher = new \ArrayObject();
			$lanzaDispatcher->append(new \SoapVar(base64_encode($xmlEntrada), XSD_STRING, null, null,'xmlEntrada', null));
			if (!empty($vDocs)) {
				for($iDoc=0; $iDoc < sizeof($vDocs); $iDoc++) {
					$sDocB64 = base64_encode($vDocs[$iDoc]);
					$lanzaDispatcher->append(new \SoapVar($sDocB64, XSD_STRING,null,null,'documentos', null));
				}
			}

			$miSoapRQ = new \SoapVar($lanzaDispatcher, SOAP_ENC_OBJECT,null,null,'lanzaDispatcher', self::NS);
			$respuesta = $clienteWS->lanzaDispatcher($miSoapRQ);

			return $respuesta;	// Nunca se ejecuta
		}
		catch (\Exception $e)
		{
			// Si se ha producido el error antes de tener disponible el cliente, vuelve a lanzar la exception para su tratamiento externo
			if (!isset($clienteWS)) {
				throw $e;
			}

			// Obtiene el array con la respuesta o lanza excepcion
			$vRetorno = $this->tratarInnerException($clienteWS, $e);

			// Convierte en el objeto apropiado, y lo devuelve
			//$oRetorno = creacionRegistroDepartamentalResponse::fromSoap($vRetorno);
			return $vRetorno;
		}
	}


	/**
	 * Codifica y enva una peticin del tipo "crearRegistro" al WS
	 * @param boolean $esRegistroEntrada Boolean que indica si se acta sobre el registro de entrada (True = registro de entrada)
	 * @param API_CREAREGISTRO $oCrearReg Objeto que contiene la informacin de la peticion
	 * @param array $vDocs Array con el contenido Base64 de los ficheros a adjuntar
	 * @return array Respuesta del WS
	 */
	public function crearRegistro($esRegistroEntrada, $oCrearReg, $vDocs)
	{
		// Prepara la informacin
		$tipoRegistro = $this->getTipoRegistro($esRegistroEntrada);

		// Convierte el objeto a texto
		$strCrearRegContent = $oCrearReg->generateString();

		// Codifica la peticin
		$xmlEntrada = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<API_CREAREGISTRO type="$tipoRegistro" formato="MASTIN"	identificador="" version="3.0" idioma_error="" validarFirma="">
$strCrearRegContent
</API_CREAREGISTRO>
XML;

		return $this->lanzaDispatcher(utf8_encode($xmlEntrada), $vDocs);
	}


	/**
	 * Codifica y enva una peticin del tipo "consultarRegistro" al WS
	 * @param boolean $esRegistroEntrada Boolean que indica si se acta sobre el registro de entrada (True = registro de entrada)
	 * @param string $numeroRegistro nmero del registro de entrada o salida a consultar
	 * @param string $fechaRegistro fecha de creacin del registro
	 * @param string $claveConsulta clave de consulta asociada al registro
	 * @param string $devolverDocumentos True: devuelven los documentos / False: no se devuelven
	 * @param string $docFirmados True: devuelve la firma de los documentos que estn firmados / False: no se devuelve
	 * @return array Respuesta del WS
	 */
	public function consultarRegistro($esRegistroEntrada, $numeroRegistro, $fechaRegistro, $claveConsulta, $devolverDocumentos, $docFirmados)
	{
		// Codifica los parametros de entrada
		$tipoRegistro = $this->getTipoRegistro($esRegistroEntrada);
		$devolverDocumentos = $this->codificarBooleano($devolverDocumentos);
		$docFirmados = $this->codificarBooleano($docFirmados);

		// Codifica la peticin
		$xmlEntrada = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<API_CONSULTAREGISTRO type="$tipoRegistro" formato="MASTIN"	identificador="" version="3.0" idioma_error="" validarFirma="">
	<DATOS_CONSULTA>
		<NUMERO_REGISTRO>$numeroRegistro</NUMERO_REGISTRO>
		<FECHA_REGISTRO>$fechaRegistro</FECHA_REGISTRO>
		<CLAVE_CONSULTA>$claveConsulta</CLAVE_CONSULTA>
		<DEVOLVER_DOCUMENTOS>$devolverDocumentos</DEVOLVER_DOCUMENTOS>
		<DOCUMENTOS_FIRMADOS>$docFirmados</DOCUMENTOS_FIRMADOS>
	</DATOS_CONSULTA>
</API_CONSULTAREGISTRO>
XML;

		return $this->lanzaDispatcher(utf8_encode($xmlEntrada), null);
	}

	/**
	 * Codifica y enva una peticin del tipo "consultarDocumento" al WS
	 * @param boolean $esRegistroEntrada Boolean que indica si se acta sobre el registro de entrada (True = registro de entrada)
	 * @param string $numeroRegistro nmero del registro de entrada o salida a consultar
	 * @param string $fechaRegistro fecha de creacin del registro
	 * @param string $claveConsulta clave de consulta asociada al registro
	 * @param string $tipoDocumento Carcter que indica el tipo de documento a solicitar
	 * @return array Respuesta del WS
	 */
	public function consultarDocumento($esRegistroEntrada, $numeroRegistro, $fechaRegistro, $claveConsulta, $tipoDocumento = 'T')
	{
		// Codifica los parametros de entrada
		$tipoRegistro = $this->getTipoRegistro($esRegistroEntrada);

		// Codifica la peticin
		$xmlEntrada = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<API_CONSULTADOCUMENTO type="$tipoRegistro" formato="MASTIN" identificador="" version="1.0" idioma_error="" validarFirma="">
	<DATOS_CONSULTA>
		<NUMERO_REGISTRO>$numeroRegistro</NUMERO_REGISTRO>
		<FECHA_REGISTRO>$fechaRegistro</FECHA_REGISTRO>
		<CLAVE_CONSULTA>$claveConsulta</CLAVE_CONSULTA>
		<TIPO_DOCUMENTO>$tipoDocumento</TIPO_DOCUMENTO>
	</DATOS_CONSULTA>
</API_CONSULTADOCUMENTO>
XML;

		return $this->lanzaDispatcher(utf8_encode($xmlEntrada), null);
	}


	/**
	 * Codifica y enva una peticin del tipo "registrarAcuse" al WS
	 * @param boolean $esRegistroEntrada Boolean que indica si se acta sobre el registro de entrada (True = registro de entrada)
	 * @param string $numeroRegistro nmero del registro de entrada o salida a consultar
	 * @param string $fechaRegistro fecha de creacin del registro
	 * @param string $claveConsulta clave de consulta asociada al registro
	 * @param string $expediente expediente asociado al registro
	 * @param string $nombreFichero nombre del fichero que se aporta
	 * @param string $codDocumento cdigo del documento
	 * @param boolean $asocioExpediente True: se asocia el documento al expediente asociado al registro. Para asociar el documento debe indicarse, adems, el expediente.
	 * @param string $entidadCertificadora ACCV
	 * @param string $formatoFirma GVAI: ideas / GVAC: capicom
	 * @param string $valorFirma firma del documento
	 * @return array Respuesta del WS
	 */
	public function registrarAcuse($esRegistroEntrada, $numeroRegistro, $fechaRegistro, $claveConsulta, $expediente,
									$nombreFichero, $codDocumento, $descDocumento, $asocioExpediente,
									$entidadCertificadora, $formatoFirma, $valorFirma, $contenidoDoc)
	{
		// Codifica los parametros de entrada
		$tipoRegistro = $this->getTipoRegistro($esRegistroEntrada);
		$asocioExpediente = $this->codificarBooleano($asocioExpediente);

		// Codifica la peticin
		$xmlEntrada = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<API_REGISTRAACUSE type="$tipoRegistro" formato="MASTIN" identificador="" version="" idioma_error="" validarFirma="">
	<DATOS_A_CONSULTAR>
		<DATOS_CONSULTA>
			<NUMERO_REGISTRO>$numeroRegistro</NUMERO_REGISTRO>
			<FECHA_REGISTRO>$fechaRegistro</FECHA_REGISTRO>
			<CLAVE_CONSULTA>$claveConsulta</CLAVE_CONSULTA>
		</DATOS_CONSULTA>
		<DOCUMENTOS_ANEXOS>
			<NOMBRE_FICHERO>$nombreFichero</NOMBRE_FICHERO>
			<CODIGO_DOCUMENTO>$codDocumento</CODIGO_DOCUMENTO>
			<DESCRIPCION_DOCUMENTO>$descDocumento</DESCRIPCION_DOCUMENTO>
			<ASOCIO_EXPEDIENTE>$asocioExpediente</ASOCIO_EXPEDIENTE>
			<TIPO_DOCUMENTO>R</TIPO_DOCUMENTO>
			<FIRMA_DOCUMENTO>
				<ENTIDAD_CERTIFICADORA>$entidadCertificadora</ENTIDAD_CERTIFICADORA>
				<FORMATO_FIRMA>$formatoFirma</FORMATO_FIRMA>
				<VALOR_FIRMA>$valorFirma</VALOR_FIRMA>
			</FIRMA_DOCUMENTO>
		</DOCUMENTOS_ANEXOS>
		<EXPEDIENTE></EXPEDIENTE>
	</DATOS_A_CONSULTAR>
</API_REGISTRAACUSE>
XML;

		// Crea un array con el documento
		$vDocs = array($contenidoDoc);

		return $this->lanzaDispatcher(utf8_encode($xmlEntrada), $vDocs);
	}




	/**
	 * Tratamiento estandarizado de las excepciones producidas en la invocacion al WS
	 *
	 * @param SoapClient	$clienteWS clienteWS utilizado en la peticion al Servicio Web
	 * @param Exception	$e Excepcion producida
	 * @return	array 	Array asociativo que contiene la respuesta del servicio
	 */
	private function tratarInnerException($clienteWS, $e)
	{
		// Comprobamos si estamos ante excepcion MTOM
		$mensaje = $e->getMessage();
		$mensaje = trim(strtolower($mensaje));
		switch ($mensaje)
		{
			case 'looks like we got no xml document' :
				// Obtiene la respuesta
				$response = $clienteWS->__getLastResponse();

				$vRetorno = $this->tratarMTOMEstandar($response);
				return $vRetorno;
				break;

			default:
				// Por defecto, vuelve a lanzar la excepcion
				throw $e;
				break;
		}
	}//tratarInnerException


	/**
	 * Trata los mensajes MTOM y reconvierte la respuesta a fomato NO MTOM. Si tiene anexos los codifica como B64
	 *
	 * Limitacin. El SoapClient de PHP no permite ver la cabecera HTTP original, sino solo la cabecera SOAP. Esto limita
	 * la forma de detectar contenido MTOM, que sigue el estandar Multipart
	 * @param array 	$response Respuesta original del WSService invocado (con contenido MTOM)
	 * @param string	$itemToReturn Elemento del cuerpo del RESPONSE a partir del cual se debe construir el array de la respuesta
	 * @return array Array asociativo de respuesta reconstrida a formato no MTOM
	 */
	protected function tratarMTOMEstandar($response, $itemToReturn = null)
	{
		//Comprobamos si existen anexos
		$mimeBoundary = '--MIME_Boundary';//Probamos con --MIME Boundary hasta mejora de deteccin
		$vBodyResponse = explode($mimeBoundary, $response); //Fraccionamos la respuesta.
		$numElementos = count($vBodyResponse);

		$srcData='';
		if ($numElementos<=1)
		{
			$mimeBoundary = '--uuid:';//Probamos de nuevo con --uuid hasta mejora de deteccin
			$vBodyResponse = explode($mimeBoundary, $response); //Fraccionamos la respuesta.
			$numElementos = count($vBodyResponse);
			$srcData = $response;
		}
		elseif ($numElementos>1)
		{
			$srcData = $vBodyResponse[1];
		}

		$vRespuesta = array();
		ini_set('pcre.backtrack_limit','100000000'); //Valor por defecto = 1000000 (aprox. 100KBytes)
		preg_match("/<[a-z]*:Envelope.*?>(.*)<\/[a-z]*:Envelope>/is", $srcData, $vRespuesta);
		if (preg_last_error()!=PREG_NO_ERROR)
		{
			//Si falta intentamos obtener el anexo con otro sistema
			$start = stripos($srcData, ':Envelope');
			$start = strripos($srcData, '<', $start - strlen($srcData));
			$end = strripos($srcData, ':Envelope>');
			$cadenaRespuesta = substr($srcData, $start, $end);
		}
		elseif (count($vRespuesta)<1)
		{
			throw new Exception('No puede ubicarse RESPONSE dentro de MTOM');
		}
		else
		{
			$cadenaRespuesta = $vRespuesta[0];
			unset($vRespuesta);
		}

		$dom = new DOMDocument('1.0');
		$dom->loadXML($cadenaRespuesta);//Cargamo el XML
		$xpath = new \DOMXpath($dom);
		$vNodoRespuesta = $xpath->query("/*[local-name()='Envelope']/*[local-name()='Body']/*/*[local-name()='respuesta']");
		$subStrXpath='';
		if (!empty($itemToReturn))
		{
			$subStrXpath = "/*[local-name()='{$itemToReturn}']";
		}
		$vNodoRespuesta = $xpath->query("/*[local-name()='Envelope']/*[local-name()='Body']/*".$subStrXpath);
		$nodoRespuesta = $vNodoRespuesta->item(0);

		if ($numElementos>0)
		{
			$oMimeParser = new WSCMimeParser();
			$oMime = $oMimeParser->decodeMTOM($vBodyResponse);
			unset($oMime->body);$oMime->body=null;gc_collect_cycles();

			$vNodoInclude = $xpath->query("//*[local-name()='Include']");
			foreach ($vNodoInclude as $nodoItem)//Recorremos los nodosXML include y sustituidmos por el contenido
			{
				$subIdBuscado = (string) $nodoItem->getAttribute('href');
				$subIdBuscado = urldecode($subIdBuscado);
				$idBuscado = '<'.substr($subIdBuscado, 4).'>';
				foreach ($oMime->parts as &$parte)
				{
					if ($idBuscado == ($parte->headers['content-id']))
					{
						if ( strtolower(substr($parte->mimetype, 0, 4)) !== 'text')//Si el tipo mime no es texto, convertimos a B64 por ser contenido binario
						{
							$parte->body = base64_encode($parte->body);
						}
						$textNode = $dom->createTextNode(($parte->body));
						$nodoItem->parentNode->replaceChild($textNode, $nodoItem);
					}
				}//Fin for partes
			}//Fin for nodos
		}

		return $this->xml_to_object($nodoRespuesta);
	}//tratarMTOMEstandar


	/**
	 * Devuelve un objeto RTSOAResponse con el contenido de la respuesta
	 * @param \DOMNode 	$root Nodo raiz de la respuesta del WS
	 * @return RTSOAResponse Objeto que contiene la respuesta del WS. Si no se puede interpretar, se devuelve un objeto sin datos
	 */
	protected function xml_to_object(&$root)
	{
		// Si no hay respuesta, devuelve una respuesta vacia
		$vNodeRespuesta = $root->getElementsByTagName('respuesta');
		if ($vNodeRespuesta->length == 0)
		{
			return new RTSOAResponse();
		}

		// Accede al nodo 'respuesta', y crea el objeto respuesta
		$nodeRespuesta = $vNodeRespuesta->item(0);
		$oResp = RTSOAResponse::fromDOM($nodeRespuesta);

		return $oResp;
	}//xml_to_object




	/**
	 * Devuelve el contenido de un fichero de aviso estandar que contiene el texto indicado
	 * @param string 	$texto Texto del aviso. Es necesario que no sea vaco, pues es el "ttulo" (link) al asunto en la Carp. Ciu.
	 * @return string Contenido del fichero de aviso.
	 */
	static public function CrearFicheroAviso($texto) {
		$texto = trim($texto);
		if (empty($texto))
		{
			throw new Exception('El parmetro $texto no puede ser vaco. Es el ttulo en la carpeta ciudadana (link)');
		}
		// Codifica la peticin
		$xmlEntrada = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<AVISO_NOTIFICACION_GRED>
	<TITULO_AVISO>SIN USO</TITULO_AVISO>
	<TEXTO_AVISO>$texto</TEXTO_AVISO>
</AVISO_NOTIFICACION_GRED>
XML;

		return utf8_encode($xmlEntrada);
	}


	/**
	 * Devuelve el contenido de un fichero de oficio estandar que contiene el texto indicado
	 * @param string 	$texto Texto del ofici
	 * @return string Contenido del fichero de oficio
	 */
	static public function CrearFicheroOficioRemision($texto) {
		// Codifica la peticin
		$xmlEntrada = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<OFICIO_REMISION_GRED>
	<TITULO_OFICIO_REMISION>SIN USO</TITULO_OFICIO_REMISION>
	<TEXTO_OFICIO_REMISION>$texto</TEXTO_OFICIO_REMISION>
</OFICIO_REMISION_GRED>
XML;

		return utf8_encode($xmlEntrada);
	}

}//End RTSOAClient









class RTSOAResponse {

	// Resultado
	private $_resultado = null;
	private $_hasResultado = false;
	public function setResultado($value) {
		$this->_resultado = $value;
		$this->_hasResultado = ($value !== null);
	}
	public function hasResultado() {
		return $this->_hasResultado;
	}
	public function getResultado() {
		return $this->_resultado;
	}

	// Document
	private $_document = array();
	private $_hasDocument = false;
	public function replaceArrayDocument($value) {
		$this->_document = $value;
		$this->_hasDocument = (isset($this->_document) && !empty($this->_document));
	}
	public function retrieveArrayDocument() {
		return $this->_document;
	}
	public function addDocument($value) {
		array_push($this->_document, $value);
		$this->_hasDocument = (isset($this->_document) && !empty($this->_document));
	}
	public function hasDocument() {
		return $this->_hasDocument;
	}
	public function getDocument($index) {
		return $this->_document[$index];
	}
	public function countDocument() {
		return count($this->_document);
	}


	static public function fromDOM($nodoRespuesta) {
		$newItem = new RTSOAResponse();

		// Si hay un resultado en la respuesta, lo incluye
		$vNodeResultado = $nodoRespuesta->getElementsByTagName('resultado');
		if ($vNodeResultado->length > 0)
		{
			$newItem->setResultado( $vNodeResultado->item(0)->nodeValue );
		}

		// Recorre los documentos aadiendolos
		$vNodeDocumentos = $nodoRespuesta->getElementsByTagName('documentos');
		if ($vNodeDocumentos->length > 0)
		{
			foreach($vNodeDocumentos as $nDoc) {
				$newItem->addDocument( RTSOADocumentResponse::fromDOM($nDoc) );
			}
		}

		return $newItem;
	}

	public function ReadAPICrearRegistroFromString($strIn) {
		$doc = new \DOMDocument();
		$doc->loadXML($strIn);

		$vAPI = $doc->getElementsByTagName('API_CREAREGISTRO');
		if ($vAPI->length <= 0) {
			return null;
		}

		$xmlAPI = $vAPI->item(0);
		$oAPI = API_CREAREGISTRO::fromDOM( $xmlAPI );

		return $oAPI;
	}

	public function ReadDatosRegistroFromString($strIn) {
		$doc = new \DOMDocument();
		$doc->loadXML($strIn);

		$vAPI = $doc->getElementsByTagName('DATOS_DEL_REGISTRO');
		if ($vAPI->length <= 0) {
			return null;
		}

		$xmlAPI = $vAPI->item(0);
		$oAPI = DATOS_DEL_REGISTRO::fromDOM( $xmlAPI );

		return $oAPI;
	}
} // RTSOAResponse



class RTSOADocumentResponse
{
	private $_nombre = null;
	private $_hasNombre = false;
	private $_tipo = null;
	private $_hasTipo = false;
	private $_contenido = null;
	private $_hasContenido = false;

	// Nombre
	public function setNombre($value) {
		$this->_nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_hasNombre;
	}
	public function getNombre() {
		return $this->_nombre;
	}


	// Tipo
	public function setTipo($value) {
		$this->_tipo = $value;
		$this->_hasTipo = ($value !== null);
	}
	public function hasTipo() {
		return $this->_hasTipo;
	}
	public function getTipo() {
		return $this->_tipo;
	}


	// Contenido
	public function setContenido($value) {
		$this->_contenido = $value;
		$this->_hasContenido = ($value !== null);
	}
	public function hasContenido() {
		return $this->_hasContenido;
	}
	public function getContenido() {
		return $this->_contenido;
	}


	static public function fromDOM($nodeDocumento) {
		$newItem = new RTSOADocumentResponse();

		$vNode = $nodeDocumento->getElementsByTagName('nombre');
		if ($vNode->length > 0)
		{
			$newItem->setNombre( $vNode->item(0)->nodeValue );
		}

		$vNode = $nodeDocumento->getElementsByTagName('tipo');
		if ($vNode->length > 0)
		{
			$newItem->setTipo( $vNode->item(0)->nodeValue );
		}

		$vNode = $nodeDocumento->getElementsByTagName('contenido');
		if ($vNode->length > 0)
		{
			$newItem->setContenido( $vNode->item(0)->nodeValue );
		}

		return $newItem;
	}

} // RTSOADocumentResponse


?>