<?php
namespace WSCOMUN\SS\VIDA_LABORAL;

use WSCOMUN\WSComunFClient;
use WSCOMUN\WSSSoapClient;
use ArrayObject;
use DateTime;
use Exception;
use SoapVar;

/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de Vida Laboral
 *
 * @package		WSClientVL
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2019 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientVidaLaboral extends WSComunFClient
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP  = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR   = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';
	private static $NAMESPACE_RESP = 'http://intermediacion.redsara.es/scsp/esquemas/V3/respuesta';


	/**
	 * Devuelve la instancia del cliente WSSSoapClient ya configurado, o null si no existe.
	 *
	 * @access	private
	 * @return	WSSSoapClient	Devuelve el objeto o null si error
	 */
	private function crearCliente() {
		$opcionesClienteWS = array (
				'soap_version' => SOAP_1_1, //SOAP 1.2
				'user_agent' => 'WSSoapClient',
				'exceptions' => true,
				'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
				'trace' => self::$MYSOAPOP_TRACE
		);

		$this->__clienteOn(self::KEYCLIENTE_SS_VIDALABORAL, true, $opcionesClienteWS);
		$clienteWS = $this->__getClient(self::KEYCLIENTE_SS_VIDALABORAL);

		return $clienteWS;
	}


	/**
	 * Realiza una peticin sncrona al servidor con una nica solicitud.
	 *
	 * @access	public
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	objSolicitudTransmision	$oSolicitud	Solicitud a enviar
	 * @return	DatosEspecificos	Respuesta del servidor
	 */
	public function peticionSincrona($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud)
	{
		try
		{
			// Crea el cliente del WS
			$clienteWS = $this->crearCliente();

			// Genera el SoapVar a enviar
			$bodyWSRequest = $this->toSOAP_petSinc($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud);

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'Peticion', self::$NAMESPACE_PET);
			$clienteWS->peticionSincrona($miSoapRQ);

			// Obtiene la respuesta como un array (en lugar de arrayObject)
			$vResp = $this->obtenerArrayRespuesta( $clienteWS->__getLastResponse() );

			// Transforma la respuesta en el array correspondientes (devuelve slo la seccin de datos especificos)
			return DatosEspecificos::fromSoap($vResp['Transmisiones']['TransmisionDatos']['DatosEspecificos']);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//peticionSincrona

	
	/**
	 * Realiza una peticin asncrona al servidor con una o varias solicitudes
	 *
	 * @access	public
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	array<objSolicitudTransmision>	$vSolicitudes	Array con las solicitudes a enviar
	 * @return	???	Respuesta del servidor
	 */
	public function peticionAsincrona($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes)
	{
		try
		{
			// Crea el cliente del WS
			$clienteWS = $this->crearCliente();
	
			// Genera el SoapVar a enviar
			$bodyWSRequest = $this->toSOAP_petAsinc($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes);
	
			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null, 'Peticion', self::$NAMESPACE_PET);
			$respuesta = $clienteWS->peticionAsincrona($miSoapRQ);
	
			// Respuesta
			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//peticionAsincrona
	
	
	/**
	 * Realiza una solicitud de respuesta a una peticin asncrona previa
	 *
	 * @access	public
	 * @param	string	$IdPeticion	Identificador de la peticin original
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje de la peticin original
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	integer	$NumElementos	Nmero de elementos de la peticion original
	 * @return	???	Respuesta del servidor
	 */
	public function solicitudRespuesta($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos)
	{
		try
		{
			// Crea el cliente del WS
			$clienteWS = $this->crearCliente();
	
			// Genera el SoapVar a enviar
			$bodyWSRequest = $this->toSOAP_SR($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos);
	
			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudRespuesta', self::$NAMESPACE_SR);
			$respuesta = $clienteWS->solicitudRespuesta($miSoapRQ);
	
			// TODO: CONVERTIR RESPUESTA EN OBJETO!!!
	
			// Respuesta
			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//solicitudRespuesta

	/**
	 * Compone el SoapVar correspondiente a la etiqueta Atributos
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	integer	$NumElementos	Nmero de elementos de la peticion original
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	string	$ns	Namespace especifico a utilizar
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_atributos($idPeticion, $numElementos, $timestamp, $codigoCertificado, $ns) {
		// Atributos
		$AtrWSLvl = new ArrayObject();
		$AtrWSLvl->append(new SoapVar($idPeticion, XSD_STRING, null, null,'IdPeticion', $ns));
		$AtrWSLvl->append(new SoapVar($numElementos, XSD_INTEGER , null, null,'NumElementos', $ns));
//		$AtrWSLvl->append(new SoapVar($timestamp->format(DateTime::ATOM), XSD_STRING, null, null,'TimeStamp', $ns));
		$AtrWSLvl->append(new SoapVar($timestamp->format("Y-m-d\TH:i:s.000P"), XSD_STRING, null, null,'TimeStamp', $ns));
		$AtrWSLvl->append(new SoapVar($codigoCertificado, XSD_STRING, null, null,'CodigoCertificado', $ns));

		return new SoapVar($AtrWSLvl, SOAP_ENC_OBJECT, null, null, 'Atributos', $ns);
	}

	/**
	 * Compone el SoapVar correspondiente a las peticiones sincronas
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	objSolicitudTransmision	$oSolicitud	Solicitud a enviar
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_petSinc($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud)
	{
		// Atributos
		$AtrSoapVar = $this->toSOAP_atributos($IdPeticion, 1, $TimeStamp, $CodigoCertificado, self::$NAMESPACE_PET);

		// SolicitudTransmision
		$SolicitudTransmisionSoapVar = $oSolicitud->toSoap($IdPeticion, $CodigoCertificado, null);

		// Solicitudes
		$SolicitudesWSRequest = new ArrayObject();
		$SolicitudesWSRequest->append($SolicitudTransmisionSoapVar);

		// Body
		$bodyWSRequest = new ArrayObject();
		$bodyWSRequest->append($AtrSoapVar);
		$bodyWSRequest->append(new SoapVar($SolicitudesWSRequest, SOAP_ENC_OBJECT, null, null, 'Solicitudes', self::$NAMESPACE_PET));

		return $bodyWSRequest;
	} //toSOAP_petSinc

	/**
	 * Compone el SoapVar correspondiente a las peticiones asincronas
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	array<objSolicitudTransmision>	$vSolicitudes	Array con las solicitudes a enviar
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_petAsinc($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes)
	{
		// Cuenta el numero de solicitudes
		$NumElementos = count($vSolicitudes);
	
		// Solicitudes
		$SolicitudesWSRequest = new ArrayObject();
	
		for ($iPet=0; $iPet < $NumElementos; $iPet++) {
			$oSolicitud = $vSolicitudes[$iPet];
	
			// SolicitudTransmision
			$SolicitudTransmisionSoapVar = $oSolicitud->toSoap($IdPeticion, $CodigoCertificado, $iPet);
	
			// Aade la solicitud de transmision al listado de solicitudes
			$SolicitudesWSRequest->append($SolicitudTransmisionSoapVar);
		}
	
		// Atributos
		$AtrSoapVar = $this->toSOAP_atributos($IdPeticion, $NumElementos, $TimeStamp, $CodigoCertificado, self::$NAMESPACE_PET);
	
		// Body
		$bodyWSRequest = new ArrayObject();
		$bodyWSRequest->append($AtrSoapVar);
		$bodyWSRequest->append(new SoapVar($SolicitudesWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitudes', self::$NAMESPACE_PET));
	
		return $bodyWSRequest;
	} //toSOAP_petAsinc
	
	/**
	 * Compone el SoapVar correspondiente a las solicitudes de respuesta
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	integer	$NumElementos	Nmero de elementos de la peticion original
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_SR($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos)
	{
		// Atributos
		$AtrSoapVar = $this->toSOAP_atributos($IdPeticion, $NumElementos, $TimeStamp, $CodigoCertificado, self::$NAMESPACE_SR);
	
		// Body
		$bodyWSRequest = new ArrayObject();
		$bodyWSRequest->append($AtrSoapVar);
	
		return $bodyWSRequest;
	} //toSOAP_SR
	
	/**
	 * Obtiene la respuesta construida como un array
	 *
	 * @param array 	$response Respuesta original del WSService invocado (sin contenido MTOM)
	 * @return array Array asociativo de respuesta (sin namespace)
	 */
	protected function obtenerArrayRespuesta($response)
	{
		$dom = new \DOMDocument('1.0');
		$dom->loadXML($response);

		$xpath = new \DOMXpath($dom);
		$vNodoRespuesta = $xpath->query("/*[local-name()='Envelope']/*[local-name()='Body']/*");
		$nodoRespuesta = $vNodoRespuesta->item(0);

		return $this->transformDOMtoArray($nodoRespuesta);
	}//obtenerArrayRespuesta


	/**
	 * Transforma un DOMNode a su equivalente en array
	 *
	 * @param \DOMNode $root Nodo raiz a transformar
	 * @return array Array asociativo de respuesta (sin namespace)
	 */
	protected function transformDOMtoArray(&$root)
	{
		$result = array();
		if ($root->hasAttributes())
		{
			$attrs = $root->attributes;
			foreach ($attrs as $attr)
			{
				$result['@attributes'][$attr->name] = $attr->value;
			}
		}
		if ($root->hasChildNodes())
		{
			$children = $root->childNodes;
			if ($children->length == 1)
			{
				$child = $children->item(0);
				if ($child->nodeType == XML_TEXT_NODE)
				{
					$result['_value'] = $child->nodeValue;
					return count($result) == 1 ? $result['_value'] : $result;
				}
			}
			$groups = array();
			foreach ($children as $child)
			{
				if (!isset($result[$child->localName]))
				{
					$result[$child->localName] = $this->transformDOMtoArray($child);
				}
				else
				{
					if (!isset($groups[$child->localName]))
					{
						$result[$child->localName] = array($result[$child->localName]);
						$groups[$child->localName] = 1;
					}
					$result[$child->localName][] = $this->transformDOMtoArray($child);
				}
			}
		}
		return $result;
	}//transformDOMtoArray


	/**
	 * Devuelve un objeto que respresenta los datos especificos a partir de la respuesta de una solicitudRespuesta asincrona
	 * @param Array	$arrayResponse	Respuesta original del servicio
	 * @param int	$numTransmision	Indice de la transmision a interpretar
	 * @return	DatosEspecificos	Objeto que representa la etiqueta DatosEspecificos, y contiene su informacin, o NULL si no existe el indice
	 */
	public function interpretarDatosEspecificos($arrayResponse, $numTransmision) {
		if (!isset($arrayResponse['respuesta']))
			return null;
		if (!isset($arrayResponse['respuesta']->Transmisiones))
			return null;
		if (!isset($arrayResponse['respuesta']->Transmisiones->TransmisionDatos))
			return null;
		
		$vTransmisionDatos = $arrayResponse['respuesta']->Transmisiones->TransmisionDatos;
		if (!isset($vTransmisionDatos[$numTransmision]))
			return null;
	
		// Transforma la respuesta en el array correspondientes (devuelve slo la seccin de datos especificos)
		return DatosEspecificos::fromSoap($vTransmisionDatos[$numTransmision]->DatosEspecificos);
	}
	
}


?>